#
# spec file for package Mesa
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# Only enable the Nouveau locking patches if you know what you're doing.
# They may fix KDE on Nouveau. They may also deadlock your userland.
%define use_broken_nouveau_locking_patches 0

%define glamor 1
%define _name_archive mesa
%define _version 11.2.2
%define with_opencl 0
%ifarch %ix86 x86_64 %arm ppc ppc64 ppc64le s390x
%define gallium_loader 1
%else
%define gallium_loader 0
%endif
%ifarch %ix86 x86_64 aarch64 %arm ppc ppc64 ppc64le
%define xvmc_support 1
%define vdpau_nouveau 1
%define vdpau_radeon 1
%else
%define xvmc_support 0
%define vdpau_nouveau 0
%define vdpau_radeon 0
%endif
%ifarch %ix86 x86_64
%define with_nine 1
%if 0%{gallium_loader} && 0%{?suse_version} > 1310
# llvm >= 3.7 not provided for <= 13.1
%define with_opencl 1
%endif
%endif
Name:           Mesa
Version:        11.2.2
Release:        157.6
Summary:        System for rendering interactive 3-D graphics
License:        MIT
Group:          System/Libraries
Url:            http://www.mesa3d.org
Source:         ftp://ftp.freedesktop.org/pub/mesa/%{version}/%{_name_archive}-%{_version}.tar.xz
Source1:        ftp://ftp.freedesktop.org/pub/mesa/%{version}/%{_name_archive}-%{_version}.tar.xz.sig
Source2:        baselibs.conf
Source3:        README.updates
Source4:        manual-pages.tar.bz2
Source6:        %{name}-rpmlintrc
Source7:        Mesa.keyring
# required for building against wayland of openSUSE 13.1
Patch0:         n_Fixed-build-against-wayland-1.2.1.patch
# to be upstreamed
Patch11:        u_Fix-crash-in-swrast-when-setting-a-texture-for-a-pix.patch
# Patch from Fedora, fix 16bpp in llvmpipe
Patch13:        u_mesa-8.0.1-fix-16bpp.patch
# Patch from Fedora, use shmget when available, under llvmpipe
Patch15:        u_mesa-8.0-llvmpipe-shmget.patch
# to be upstreamed
Patch17:        u_st-va-hardlink-driver-instances-to-gallium_drv_video.patch
# never to be upstreamed
Patch18:        n_VDPAU-XVMC-libs-Replace-hardlinks-with-copies.patch
# Already upstream
Patch21:        n_Define-GLAPIVAR-separate-from-GLAPI.patch
Patch22:        U_r300g-Set-R300_VAP_CNTL-on-RSxxx-to-avoid-triangle-flickering.patch
Patch23:        U_gallivm-disable-avx512-features.patch
Patch24:        U_cso-don-t-release-sampler-states-that-are-bound.patch

# Nouveau multithreading workarounds from https://github.com/imirkin/mesa/commits/locking
Patch61:        N_01-WIP-nouveau-add-locking.patch
Patch62:        N_02-nouveau-more-locking-make-sure-that-fence-work-is-always-done-with-the-push-mutex-acquired.patch
Patch63:        N_03-nv30-locking-fixes.patch
Patch64:        N_04-nv50-Fix-double-lock-in-nv50_hw_sm_get_query_result.patch
Patch65:        N_05-Use-nv50_render_condition-in-nv50_blitctx_post_blit.patch

BuildRequires:  autoconf >= 2.60
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  fdupes
BuildRequires:  flex
BuildRequires:  gcc-c++
BuildRequires:  imake
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  python-base
BuildRequires:  python-mako
BuildRequires:  python-xml
BuildRequires:  pkgconfig(dri2proto)
BuildRequires:  pkgconfig(dri3proto)
BuildRequires:  pkgconfig(expat)
BuildRequires:  pkgconfig(glproto)
BuildRequires:  pkgconfig(libdrm) >= 2.4.60
BuildRequires:  pkgconfig(libdrm_amdgpu) >= 2.4.63
BuildRequires:  pkgconfig(libdrm_nouveau) >= 2.4.66
BuildRequires:  pkgconfig(libdrm_radeon) >= 2.4.56
BuildRequires:  pkgconfig(libkms) >= 1.0.0
BuildRequires:  pkgconfig(libudev) > 151
BuildRequires:  pkgconfig(libva)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(presentproto)
BuildRequires:  pkgconfig(vdpau) >= 0.4.1
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(x11-xcb)
BuildRequires:  pkgconfig(xcb-dri2)
BuildRequires:  pkgconfig(xcb-dri3)
BuildRequires:  pkgconfig(xcb-glx)
BuildRequires:  pkgconfig(xcb-present)
BuildRequires:  pkgconfig(xdamage)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xfixes)
BuildRequires:  pkgconfig(xshmfence)
BuildRequires:  pkgconfig(xvmc)
BuildRequires:  pkgconfig(xxf86vm)
BuildRequires:  pkgconfig(zlib)
Provides:       Mesa7 = %{version}
Obsoletes:      Mesa7 < %{version}
Provides:       intel-i810-Mesa = %{version}
Obsoletes:      intel-i810-Mesa < %{version}
Provides:       Mesa-libIndirectGL1 = %{version}
Obsoletes:      Mesa-libIndirectGL1 < %{version}
Provides:       Mesa-nouveau3d = %{version}
Provides:       xorg-x11-Mesa = %{version}
Obsoletes:      Mesa-nouveau3d < %{version}
Obsoletes:      xorg-x11-Mesa < %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%ifarch %arm
BuildRequires:  pkgconfig(libdrm_freedreno) >= 2.4.67
%endif
%ifarch x86_64 %ix86
BuildRequires:  libelf-devel
BuildRequires:  pkgconfig(libdrm_intel) >= 2.4.61
%endif
%if 0%{?suse_version} >= 1310
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-server)
%endif
%ifarch aarch64 %arm ppc64 ppc64le s390x %ix86 x86_64
BuildRequires:  llvm-devel
BuildRequires:  ncurses-devel
%endif
#!BuildIgnore:  python

%if 0%{with_opencl}
BuildRequires:  libclc
BuildRequires:  llvm-clang-devel
%endif

%description
Mesa is a 3-D graphics library with an API which is very similar to
that of OpenGL.* To the extent that Mesa utilizes the OpenGL command
syntax or state machine, it is being used with authorization from
Silicon Graphics, Inc.(SGI). However, the author does not possess an
OpenGL license from SGI, and makes no claim that Mesa is in any way a
compatible replacement for OpenGL or associated with SGI. Those who
want a licensed implementation of OpenGL should contact a licensed
vendor.

Please do not refer to the library as MesaGL (for legal reasons). It's
just Mesa or The Mesa 3-D graphics library.

* OpenGL is a trademark of Silicon Graphics Incorporated.

%package devel
Summary:        Libraries, includes and more to develop Mesa applications
Group:          Development/Libraries/X11
Requires:       Mesa = %{version}
Requires:       Mesa-dri-devel = %{version}
Requires:       Mesa-libEGL-devel = %{version}
Requires:       Mesa-libGL-devel = %{version}
Requires:       Mesa-libGLESv1_CM-devel = %{version}
Requires:       Mesa-libGLESv2-devel = %{version}
Requires:       Mesa-libglapi-devel = %{version}
Requires:       libOSMesa-devel = %{version}
Requires:       libgbm-devel
Provides:       Mesa-devel-static = %{version}
Provides:       xorg-x11-Mesa-devel = %{version}
Obsoletes:      Mesa-devel-static < %{version}
Obsoletes:      xorg-x11-Mesa-devel < %{version}
Provides:       Mesa-libIndirectGL-devel = %{version}
Obsoletes:      Mesa-libIndirectGL-devel < %{version}
%if 0%{?suse_version} >= 1310
Requires:       libwayland-egl-devel
%endif

%description devel
Mesa is a 3-D graphics library with an API which is very similar to
that of OpenGL.* To the extent that Mesa utilizes the OpenGL command
syntax or state machine, it is being used with authorization from
Silicon Graphics, Inc.(SGI). However, the author does not possess an
OpenGL license from SGI, and makes no claim that Mesa is in any way a
compatible replacement for OpenGL or associated with SGI. Those who
want a licensed implementation of OpenGL should contact a licensed
vendor.

Please do not refer to the library as MesaGL (for legal reasons). It's
just Mesa or The Mesa 3-D graphics library.

* OpenGL is a trademark of Silicon Graphics Incorporated.

%package -n Mesa-libEGL1
# Kudos to Debian for the descriptions
Summary:        Free implementation of the EGL API
Group:          System/Libraries

%description -n Mesa-libEGL1
This package contains the EGL native platform graphics interface
library. EGL provides a platform-agnostic mechanism for creating
rendering surfaces for use with other graphics libraries, such as
OpenGL|ES and OpenVG.

This package contains modules to interface with the existing system
GLX or DRI2 drivers to provide OpenGL via EGL. The Mesa main package
provides drivers to provide hardware-accelerated OpenGL|ES and OpenVG
support.

%package -n Mesa-libEGL-devel
Summary:        Development files for the EGL API
Group:          Development/Libraries/C and C++
Requires:       Mesa-libEGL1 = %{version}
# Other requires taken care of by pkgconfig already

%description -n Mesa-libEGL-devel
This package contains the development environment required for
compiling programs against EGL native platform graphics interface
library. EGL provides a platform-agnostic mechanism for creating
rendering surfaces for use with other graphics libraries, such as
OpenGL|ES and OpenVG.

This package provides the development environment for compiling
programs against the EGL library.

%package -n Mesa-libGL1
Summary:        The GL/GLX runtime of the Mesa 3D graphics library
Group:          System/Libraries
Requires:       Mesa = %{version}

%description -n Mesa-libGL1
Mesa is a software library for 3D computer graphics that provides a
generic OpenGL implementation for rendering three-dimensional
graphics.

GLX ("OpenGL Extension to the X Window System") provides the
interface connecting OpenGL and the X Window System: it enables
programs wishing to use OpenGL to do so within a window provided by
the X Window System.

%package -n Mesa-libGL-devel
Summary:        GL/GLX development files of the OpenGL API
Group:          Development/Libraries/C and C++
Requires:       Mesa-libGL1 = %{version}

%description -n Mesa-libGL-devel
Mesa is a software library for 3D computer graphics that provides a
generic OpenGL implementation for rendering three-dimensional
graphics.

This package includes headers and static libraries for compiling
programs with Mesa.

%package -n Mesa-libGLESv1_CM1
Summary:        Free implementation of the OpenGL|ES 1.x Common Profile API
Group:          System/Libraries

%description -n Mesa-libGLESv1_CM1
OpenGL|ES is a cross-platform API for full-function 2D and 3D
graphics on embedded systems - including consoles, phones, appliances
and vehicles. It contains a subset of OpenGL plus a number of
extensions for the special needs of embedded systems.

OpenGL|ES 1.x provides an API for fixed-function hardware.

%package -n Mesa-libGLESv1_CM-devel
Summary:        Development files for the OpenGL ES 1.x API
Group:          Development/Libraries/C and C++
Requires:       Mesa-libGLESv1_CM1 = %{version}
Requires:       pkgconfig(egl)

%description -n Mesa-libGLESv1_CM-devel
OpenGL|ES is a cross-platform API for full-function 2D and 3D
graphics on embedded systems - including consoles, phones, appliances
and vehicles. It contains a subset of OpenGL plus a number of
extensions for the special needs of embedded systems.

OpenGL|ES 1.x provides an API for fixed-function hardware.

This package provides a development environment for building programs
using the OpenGL|ES 1.x APIs.

%package -n Mesa-libGLESv2-2
Summary:        Free implementation of the OpenGL|ES 2.x API
Group:          System/Libraries

%description -n Mesa-libGLESv2-2
OpenGL|ES is a cross-platform API for full-function 2D and 3D
graphics on embedded systems - including consoles, phones, appliances
and vehicles. It contains a subset of OpenGL plus a number of
extensions for the special needs of embedded systems.

OpenGL|ES 2.x provides an API for programmable hardware including
vertex and fragment shaders.

The libGLESv2.so.2 library provides symbols for all OpenGL ES 2 and
ES 3 entry points.

%package -n Mesa-libGLESv2-devel
Summary:        Development files for the OpenGL ES 2.x API
Group:          Development/Libraries/C and C++
Requires:       Mesa-libGLESv2-2 = %{version}
Requires:       pkgconfig(egl)

%description -n Mesa-libGLESv2-devel
OpenGL|ES is a cross-platform API for full-function 2D and 3D
graphics on embedded systems - including consoles, phones, appliances
and vehicles. It contains a subset of OpenGL plus a number of
extensions for the special needs of embedded systems.

OpenGL|ES 2.x provides an API for programmable hardware including
vertex and fragment shaders.

This package provides a development environment for building
applications using the OpenGL|ES 2.x APIs.

%package -n Mesa-libGLESv3-devel
Summary:        Development files for the OpenGL ES 3.x API
Group:          Development/Libraries/C and C++
Requires:       Mesa-libGLESv2-2 = %{version}
Requires:       pkgconfig(egl)

%description -n Mesa-libGLESv3-devel
OpenGL|ES is a cross-platform API for full-function 2D and 3D
graphics on embedded systems - including consoles, phones, appliances
and vehicles. It contains a subset of OpenGL plus a number of
extensions for the special needs of embedded systems.

This package provides a development environment for building
applications using the OpenGL|ES 3.x APIs.

%package -n libOSMesa9
Summary:        Mesa Off-screen rendering extension
Group:          System/Libraries

%description -n libOSMesa9
OSmesa is a Mesa extension that allows programs to render to an
off-screen buffer using the OpenGL API without having to create a
rendering context on an X Server. It uses a pure software renderer.

%package -n libOSMesa-devel
Summary:        Development files for the Mesa Offscreen Rendering extension
Group:          Development/Libraries/C and C++
Requires:       libOSMesa9 = %{version}

%description -n libOSMesa-devel
Development files for the OSmesa Mesa extension that allows programs to render to an
off-screen buffer using the OpenGL API without having to create a
rendering context on an X Server. It uses a pure software renderer.

%package -n Mesa-libglapi0
Summary:        Free implementation of the GL API
Group:          System/Libraries

%description -n Mesa-libglapi0
The Mesa GL API module is responsible for dispatching all the gl*
functions. It is intended to be mainly used by the Mesa-libGLES*
packages.

%package -n Mesa-libglapi-devel
Summary:        Development files for the free implementation of the GL API
Group:          Development/Libraries/C and C++
Requires:       Mesa-libglapi0 = %{version}

%description -n Mesa-libglapi-devel
Development files for the Mesa GL API module which is responsible for
dispatching all the gl* functions. It is intended to be mainly used by
the Mesa-libGLES* packages.

%package -n Mesa-dri-devel
Summary:        Development files for the DRI API
Group:          Development/Libraries/C and C++
Requires:       Mesa = %{version}

%description -n Mesa-dri-devel
This package contains the development environment required for
compiling programs and libraries using the DRI API.

%package -n Mesa-dri-nouveau
Summary:        Mesa DRI plug-in for 3D acceleration via Nouveau
Group:          System/Libraries
Requires:       Mesa = %{version}
Supplements:    modalias(xorg-x11-server:pci:v000012D2d*sv*sd*bc03sc*i*)
Supplements:    modalias(xorg-x11-server:pci:v000010DEd*sv*sd*bc03sc*i*)

%description -n Mesa-dri-nouveau
This package contains nouveau_dri.so, which is necessary for
Nouveau's 3D acceleration to work. It is packaged separately
since it is still experimental.

%package -n libgbm1
Summary:        Generic buffer management API
Group:          System/Libraries

%description -n libgbm1
This package contains the GBM buffer management library. It provides
a mechanism for allocating buffers for graphics rendering tied to
Mesa.

GBM is intended to be used as a native platform for EGL on drm or
openwfd.

%package -n libgbm-devel
Summary:        Development files for the EGL API
Group:          Development/Libraries/C and C++
Requires:       libgbm1 = %{version}

%description -n libgbm-devel
This package contains the GBM buffer management library. It provides
a mechanism for allocating buffers for graphics rendering tied to
Mesa.

GBM is intended to be used as a native platform for EGL on drm or
openwfd.

This package provides the development environment for compiling
programs against the GBM library.

%if 0%{?suse_version} >= 1310
%package -n libwayland-egl1
Summary:        Additional egl functions for wayland
Group:          System/Libraries

%description -n libwayland-egl1
This package provides additional functions for egl-using programs
that run within the wayland framework. This allows for applications
that need not run full-screen and cooperate with a compositor.

%package -n libwayland-egl-devel
Summary:        Development files for libwayland-egl1
Group:          Development/Libraries/C and C++
Requires:       libwayland-egl1 = %{version}

%description -n libwayland-egl-devel
This package is required to link wayland client applications to the EGL
implementation of Mesa.
%endif

%if 0%{?with_nine}
%package libd3d
Summary:        Mesa Direct3D9 state tracker
# Manually provide d3d library (bnc#918294)
Group:          System/Libraries
%ifarch x86_64 s390x ppc64le aarch64
Provides:       d3dadapter9.so.1()(64bit)
%else
Provides:       d3dadapter9.so.1
%endif

%description libd3d
Mesa Direct3D9 state tracker

%package libd3d-devel
Summary:        Mesa Direct3D9 state tracker development package
Group:          System/Libraries
Requires:       %{name}-libd3d = %{version}

%description libd3d-devel
Mesa Direct3D9 state tracker development package
%endif

%package -n libxatracker2
Version:        1.0.0
Release:        157.6
Summary:        XA state tracker
Group:          System/Libraries

%description -n libxatracker2
This package contains the XA state tracker for gallium3D driver.
It superseeds the Xorg state tracker and provides an infrastructure
to accelerate Xorg 2D operations. It is currently used by vmwgfx
video driver.

%package -n libxatracker-devel
Version:        1.0.0
Release:        157.6
Summary:        Development files for the XA API
Group:          Development/Libraries/C and C++
Requires:       libxatracker2 = %{version}

%description -n libxatracker-devel
This package contains the XA state tracker for gallium3D driver.
It superseeds the Xorg state tracker and provides an infrastructure
to accelerate Xorg 2D operations. It is currently used by vmwgfx
video driver.

This package provides the development environment for compiling
programs against the XA state tracker.

%package -n libXvMC_nouveau
Summary:        XVMC state tracker for Nouveau
Group:          System/Libraries

%description -n libXvMC_nouveau
This package contains the XvMC state tracker for Nouveau. This is
still "work in progress", i.e. expect poor video quality, choppy
videos and artefacts all over.

%package -n libXvMC_r600
Summary:        XVMC state tracker for R600
Group:          System/Libraries

%description -n libXvMC_r600
This package contains the XvMC state tracker for R600. This is
still "work in progress", i.e. expect poor video quality, choppy
videos and artefacts all over.

%package -n libvdpau_nouveau
Summary:        XVMC state tracker for Nouveau
Group:          System/Libraries
Supplements:    xf86-video-nouveau

%description -n libvdpau_nouveau
This package contains the VDPAU state tracker for Nouveau.

%package -n libvdpau_r300
Summary:        XVMC state tracker for R300
Group:          System/Libraries
Supplements:    xf86-video-ati

%description -n libvdpau_r300
This package contains the VDPAU state tracker for R300.

%package -n libvdpau_r600
Summary:        XVMC state tracker for R600
Group:          System/Libraries
Supplements:    xf86-video-ati

%description -n libvdpau_r600
This package contains the VDPAU state tracker for R600.

%package -n libvdpau_radeonsi
Summary:        XVMC state tracker for radeonsi
Group:          System/Libraries
Supplements:    xf86-video-ati

%description -n libvdpau_radeonsi
This package contains the VDPAU state tracker for radeonsi.

%if 0%{with_opencl}
%package libOpenCL
Summary:        Mesa OpenCL implementation
Group:          System/Libraries

%description libOpenCL
This package contains the Mesa OpenCL implementation or GalliumCompute.
%endif

%package libva
Summary:        Mesa VA-API implementation
Group:          System/Libraries
Supplements:    Mesa

%description libva
This package contains the Mesa VA-API implementation provided through gallium.

%prep
%setup -q -n %{_name_archive}-%{_version} -b4
# remove some docs
rm -rf docs/README.{VMS,WIN32,OS2}
%if 0%{?suse_version} < 1320
# required for building against wayland of openSUSE 13.1
%patch0 -p1
%endif
### disabled, but not dropped yet; these still need investigation in
### order to figure out whether the issue is still reproducable and
### hence a fix is required
#%patch11 -p1
#%patch15 -p1
#%patch13 -p1
%patch17 -p1
%patch18 -p1
%patch21 -p1
%patch22 -p1
%patch23 -p1
%patch24 -p1

%if %{use_broken_nouveau_locking_patches}
%patch61 -p1
%patch62 -p1
%patch63 -p1
%patch64 -p1
%patch65 -p1
%endif

%build
%if 0%{?suse_version} >= 1310
egl_platforms=x11,drm,wayland
%else
egl_platforms=x11,drm
%endif
autoreconf -fvi
###           --with-gallium-drivers=r300,r600,radeonsi,nouveau,swrast,svga \
###           --with-gallium-drivers=r300,r600,nouveau,swrast,svga \
###           --with-gallium-drivers=r300,nouveau,swrast,svga \
%configure --enable-gles1 \
           --enable-gles2 \
           --enable-dri \
           --with-egl-platforms=$egl_platforms \
           --enable-shared-glapi \
           --enable-texture-float \
           --enable-osmesa \
           --enable-dri3 \
           --enable-shader-cache \
           %{?with_nine:--enable-nine} \
%if %{glamor}
           --enable-gbm \
           --enable-glx-tls \
%endif
%if 0%{?suse_version} < 1315
           --with-dri-searchpath=%{_libdir}/dri/updates:%{_libdir}/dri \
%else
           --with-dri-searchpath=%{_libdir}/dri \
%endif
%ifarch %ix86 x86_64
           --enable-xa \
           --enable-gallium-llvm \
           --with-dri-drivers=i915,i965,nouveau,r200,radeon \
%if 0%{with_opencl}
           --enable-opencl \
           --enable-opencl-icd \
%endif
           --enable-llvm-shared-libs \
           --enable-r600-llvm-compiler \
           --with-gallium-drivers=r300,r600,radeonsi,nouveau,swrast,svga \
           --enable-vdpau \
           --enable-va \
           --enable-xvmc \
%endif
%ifarch aarch64 %arm ppc64 ppc64le
           --enable-xa \
           --enable-gallium-llvm \
           --with-dri-drivers=nouveau \
           --enable-llvm-shared-libs \
%ifarch %arm aarch64
           --with-gallium-drivers=r300,r600,nouveau,swrast,svga,freedreno,vc4 \
%else
           --with-gallium-drivers=r300,r600,nouveau,swrast,svga \
%endif
           --enable-vdpau \
           --enable-xvmc \
%endif
%ifarch ia64 ppc hppa
           --with-dri-drivers=nouveau,r200,radeon \
           --with-gallium-drivers=r300,r600,nouveau,swrast \
%endif
%ifarch s390
           --with-dri-drivers=swrast \
           --with-gallium-drivers=swrast \
%endif
%ifarch s390x
        --enable-xa \
        --enable-gallium-llvm \
        --with-dri-drivers=swrast \
        --with-gallium-drivers=swrast,svga \
%endif
        CFLAGS="%{optflags} -DNDEBUG"
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
find %{buildroot} -type f -name "*.la" -delete -print

# Make a symlink to libGL.so.1.2 for compatibility (bnc#809359, bnc#831306)
test -f %{buildroot}%{_libdir}/libGL.so.1.2 || \
  ln -s `readlink %{buildroot}%{_libdir}/libGL.so.1` %{buildroot}%{_libdir}/libGL.so.1.2

for dir in ../xc/doc/man/{GL/gl,GL/glx}; do
 pushd $dir
   xmkmf -a
   make %{?_smp_mflags}
   make install.man DESTDIR=%{buildroot} MANPATH=%{_mandir} LIBMANSUFFIX=3gl
 popd
done
%if 0%{?suse_version} < 1315
#DRI driver update mechanism
mkdir -p %{buildroot}%{_libdir}/dri/updates
install -m 644 $RPM_SOURCE_DIR/README.updates \
  %{buildroot}%{_libdir}/dri/updates
%endif

%fdupes -s %{buildroot}/%{_mandir}

%post   -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%post   -n Mesa-libEGL1 -p /sbin/ldconfig

%postun -n Mesa-libEGL1 -p /sbin/ldconfig

%post   -n Mesa-libGL1 -p /sbin/ldconfig

%postun -n Mesa-libGL1 -p /sbin/ldconfig

%post   -n Mesa-libGLESv1_CM1 -p /sbin/ldconfig

%postun -n Mesa-libGLESv1_CM1 -p /sbin/ldconfig

%post   -n Mesa-libGLESv2-2 -p /sbin/ldconfig

%postun -n Mesa-libGLESv2-2 -p /sbin/ldconfig

%post   -n libOSMesa9 -p /sbin/ldconfig

%postun -n libOSMesa9 -p /sbin/ldconfig

%post   -n libgbm1 -p /sbin/ldconfig

%postun -n libgbm1 -p /sbin/ldconfig

%ifarch aarch64 %ix86 x86_64 %arm ppc64 ppc64le s390x
%post   -n libxatracker2 -p /sbin/ldconfig

%postun -n libxatracker2 -p /sbin/ldconfig
%endif

%if %{xvmc_support}
%post   -n libXvMC_nouveau -p /sbin/ldconfig

%postun -n libXvMC_nouveau -p /sbin/ldconfig

%post   -n libXvMC_r600 -p /sbin/ldconfig

%postun -n libXvMC_r600 -p /sbin/ldconfig
%endif

%if %{vdpau_radeon}
%post   -n libvdpau_r300 -p /sbin/ldconfig

%postun -n libvdpau_r300 -p /sbin/ldconfig

%post   -n libvdpau_r600 -p /sbin/ldconfig

%postun -n libvdpau_r600 -p /sbin/ldconfig
%endif

%ifarch %ix86 x86_64
%post   -n libvdpau_radeonsi -p /sbin/ldconfig

%postun -n libvdpau_radeonsi -p /sbin/ldconfig
%endif

%post   -n Mesa-libglapi0 -p /sbin/ldconfig

%postun -n Mesa-libglapi0 -p /sbin/ldconfig

%if 0%{?suse_version} >= 1310
%post   -n libwayland-egl1 -p /sbin/ldconfig

%postun -n libwayland-egl1 -p /sbin/ldconfig
%endif

%if 0%{?with_nine}
%post libd3d -p /sbin/ldconfig

%postun libd3d -p /sbin/ldconfig
%endif

%if 0%{with_opencl}
%post   libOpenCL -p /sbin/ldconfig

%postun libOpenCL -p /sbin/ldconfig
%endif

%post libva -p /sbin/ldconfig

%postun libva -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc docs/README* docs/COPYING
%config %{_sysconfdir}/drirc
%dir %{_libdir}/dri
%if 0%{?suse_version} < 1315
%{_libdir}/dri/updates
%endif
%{_libdir}/dri/*_dri.so
%exclude %{_libdir}/dri/nouveau_dri.so
%exclude %{_libdir}/dri/nouveau_vieux_dri.so
%if 0%{with_opencl}
# only built with opencl
%dir %{_libdir}/gallium-pipe/
%{_libdir}/gallium-pipe/pipe_*.so
%endif

%files -n Mesa-libEGL1
%defattr(-,root,root)
%{_libdir}/libEGL.so.1*

%files -n Mesa-libEGL-devel
%defattr(-,root,root)
%{_includedir}/EGL
%{_includedir}/KHR
%{_libdir}/libEGL.so
%{_libdir}/pkgconfig/egl.pc

%files -n Mesa-libGL1
%defattr(-,root,root)
%{_libdir}/libGL.so.1*

%files -n Mesa-libGL-devel
%defattr(-,root,root)
%dir %{_includedir}/GL
%{_includedir}/GL/*.h
%exclude %{_includedir}/GL/osmesa.h
%{_libdir}/libGL.so
%{_libdir}/pkgconfig/gl.pc
%{_mandir}/man3/gl[A-Z]*

%files -n Mesa-libGLESv1_CM1
%defattr(-,root,root)
%{_libdir}/libGLESv1_CM.so.1*

%files -n Mesa-libGLESv1_CM-devel
%defattr(-,root,root)
%{_includedir}/GLES
%{_libdir}/libGLESv1_CM.so
%{_libdir}/pkgconfig/glesv1_cm.pc

%files -n Mesa-libGLESv2-2
%defattr(-,root,root)
%{_libdir}/libGLESv2.so.2*

%files -n Mesa-libGLESv2-devel
%defattr(-,root,root)
%{_includedir}/GLES2
%{_libdir}/libGLESv2.so
%{_libdir}/pkgconfig/glesv2.pc

%files -n Mesa-libGLESv3-devel
%defattr(-,root,root)
%{_includedir}/GLES3
#%_libdir/libGLESv3.so
#%_libdir/pkgconfig/glesv3.pc

%files -n libOSMesa9
%defattr(-,root,root)
%{_libdir}/libOSMesa.so.8.0.0
%{_libdir}/libOSMesa.so.8

%files -n libOSMesa-devel
%defattr(-,root,root)
%{_includedir}/GL/osmesa.h
%{_libdir}/libOSMesa.so
%{_libdir}/pkgconfig/osmesa.pc

%if 0%{?suse_version} >= 1310
%files -n libwayland-egl1
%defattr(-,root,root)
%{_libdir}/libwayland-egl.so.1*

%files -n libwayland-egl-devel
%defattr(-,root,root)
%{_libdir}/libwayland-egl.so
%{_libdir}/pkgconfig/wayland-egl.pc
%endif

%files -n libgbm1
%defattr(-,root,root)
%{_libdir}/libgbm.so.1*

%files -n libgbm-devel
%defattr(-,root,root)
%{_includedir}/gbm.h
%{_libdir}/libgbm.so
%{_libdir}/pkgconfig/gbm.pc

%ifarch aarch64 %ix86 x86_64 %arm ppc64 ppc64le s390x
%files -n libxatracker2
%defattr(-,root,root)
%{_libdir}/libxatracker.so.2*

%files -n libxatracker-devel
%defattr(-,root,root)
%{_includedir}/xa_*.h
%{_libdir}/libxatracker.so
%{_libdir}/pkgconfig/xatracker.pc
%endif

%if %{xvmc_support}
%files -n libXvMC_nouveau
%defattr(-,root,root)
%{_libdir}/libXvMCnouveau.so
%{_libdir}/libXvMCnouveau.so.1
%{_libdir}/libXvMCnouveau.so.1.0
%{_libdir}/libXvMCnouveau.so.1.0.0

%files -n libXvMC_r600
%defattr(-,root,root)
%{_libdir}/libXvMCr600.so
%{_libdir}/libXvMCr600.so.1
%{_libdir}/libXvMCr600.so.1.0
%{_libdir}/libXvMCr600.so.1.0.0
%endif

%if %{vdpau_nouveau}
%files -n libvdpau_nouveau
%defattr(-,root,root)
%{_libdir}/vdpau/libvdpau_nouveau.so
%{_libdir}/vdpau/libvdpau_nouveau.so.1
%{_libdir}/vdpau/libvdpau_nouveau.so.1.0
%{_libdir}/vdpau/libvdpau_nouveau.so.1.0.0
%endif

%if %{vdpau_radeon}
%files -n libvdpau_r300
%defattr(-,root,root)
%{_libdir}/vdpau/libvdpau_r300.so
%{_libdir}/vdpau/libvdpau_r300.so.1
%{_libdir}/vdpau/libvdpau_r300.so.1.0
%{_libdir}/vdpau/libvdpau_r300.so.1.0.0

%files -n libvdpau_r600
%defattr(-,root,root)
%{_libdir}/vdpau/libvdpau_r600.so
%{_libdir}/vdpau/libvdpau_r600.so.1
%{_libdir}/vdpau/libvdpau_r600.so.1.0
%{_libdir}/vdpau/libvdpau_r600.so.1.0.0
%endif

%ifarch %ix86 x86_64
%files -n libvdpau_radeonsi
%defattr(-,root,root)
%{_libdir}/vdpau/libvdpau_radeonsi.so
%{_libdir}/vdpau/libvdpau_radeonsi.so.1
%{_libdir}/vdpau/libvdpau_radeonsi.so.1.0
%{_libdir}/vdpau/libvdpau_radeonsi.so.1.0.0
%endif

%files -n Mesa-libglapi0
%defattr(-,root,root)
%{_libdir}/libglapi.so.0*

%files -n Mesa-libglapi-devel
%defattr(-,root,root)
%{_libdir}/libglapi.so

%files -n Mesa-dri-devel
%defattr(-,root,root)
%{_includedir}/GL/internal
%{_libdir}/pkgconfig/dri.pc

%ifarch %ix86 x86_64 aarch64 %arm ppc64 ppc64le ia64 ppc hppa
%files -n Mesa-dri-nouveau
%{_libdir}/dri/nouveau_dri.so
%{_libdir}/dri/nouveau_vieux_dri.so
%endif

%files devel
%defattr(-,root,root)
%doc docs/*.html

%if 0%{?with_nine}
%files libd3d
%defattr(-,root,root)
%dir %{_libdir}/d3d/
%{_libdir}/d3d/*.so.*
#%{_sysconfdir}/OpenCL/vendors/mesa.icd

%files libd3d-devel
%defattr(-,root,root)
%{_libdir}/pkgconfig/d3d.pc
%{_includedir}/d3dadapter/
%{_libdir}/d3d/*.so
%endif

%if 0%{with_opencl}
%files libOpenCL
%defattr(-,root,root)
%dir %{_sysconfdir}/OpenCL
%dir %{_sysconfdir}/OpenCL/vendors
%{_sysconfdir}/OpenCL/vendors/mesa.icd
%{_libdir}/libMesaOpenCL.so*
%endif

%ifnarch s390 s390x
%files libva
%defattr(-,root,root)
%dir %{_libdir}/dri
%{_libdir}/dri/*_drv_video.so
%endif

%changelog
* Fri Dec 30 2016 dmueller@suse.com
- fix build on s390x (bsc#1015700)
* Wed Dec 14 2016 mstaudt@suse.com
- Mesa.spec: Fix build on aarch64
  As reported in (boo#1015012).
* Mon Dec 12 2016 mstaudt@suse.com
- U_cso-don-t-release-sampler-states-that-are-bound.patch:
  This avoids Radeon hangs due to a use-after-free bug in Gallium.
  Fixes (boo#1015012), (fdo#93649)
* Mon Nov 21 2016 sndirsch@suse.com
- baselibs.conf: enabled build of 32bit Mesa-dri-nouveau package,
  e.g. required for Steam (bnc#1011156)
* Mon Nov  7 2016 msrb@suse.com
- U_gallivm-disable-avx512-features.patch:
  Fix crashes on some Skykake CPUs by disabling avx512 features
  (bsc#980557, bsc#981532, bnc#1008295).
* Tue Nov  1 2016 dleuenberger@suse.com
- Replace Supplements: xf86-video-nouveau with the two modalias
  supplements that are available in xf86-video-nouveau: the latter
  is supplementing xf86-xorg-server, which results in the driver to
  always be installed and in consequence also Mesa-dri-nouveau.
  This is not what was intended; Due to some mistrust if the
  modalias supplements really catches ALL cases I preferred risking
  the dri driver to be less often installed than risking
  xf86-video-nouveau to possibly be missing too (boo#1007703).
* Mon Oct 24 2016 sndirsch@suse.com
- let Mesa-dri-nouveau supplement xf86-video-nouveau, so it  gets
  preselected as well once hardware supplements for Mesa-dri-nouveau
  match (bnc#1005323)
* Mon Oct 17 2016 mstaudt@suse.com
- Mesa.spec: %%ifdef'd out patches by mistake
* Mon Oct 17 2016 mstaudt@suse.com
- Split off nouveau*_dri.so into Mesa-dri-nouveau.
  Nouveau's 3D support is too unstable to enable by default.
* Mon Oct 17 2016 mstaudt@suse.com
- Mesa.spec: Disable Nouveau locking patches by default
* Mon Oct 17 2016 mstaudt@suse.com
- Merge N_06-nvc0-Fix-backport-compilation-in-nvc0_draw_vbo.patch
  into N_01-WIP-nouveau-add-locking.patch
* Thu Oct  6 2016 mstaudt@suse.com
- N_01-WIP-nouveau-add-locking.patch
  N_02-nouveau-more-locking-make-sure-that-fence-work-is-always-done-with-the-push-mutex-acquired.patch
  N_03-nv30-locking-fixes.patch
  N_04-nv50-Fix-double-lock-in-nv50_hw_sm_get_query_result.patch
  N_05-Use-nv50_render_condition-in-nv50_blitctx_post_blit.patch
  N_06-nvc0-Fix-backport-compilation-in-nvc0_draw_vbo.patch
  Backport nouveau locking workaround to enable multithreading.
  Source: https://github.com/imirkin/mesa/commits/locking
  According to the author, crashes may still happen, but much more rarely.
  Tested on GK107.
  N_04-* and N_05-* include untested fixes for nv50.
  Fixes (boo#997171) as suggested in (fdo#91632).
* Fri Sep  9 2016 mstaudt@suse.com
- U_r300g-Set-R300_VAP_CNTL-on-RSxxx-to-avoid-triangle-flickering.patch:
  Initialize RSxxx chipsets correctly (bsc#985650)
* Mon May  9 2016 mimi.vx@gmail.com
- update to 11.2.2
- removed upstreamed patches:
    + u_dri2-Check-for-dummyContext-to-see-if-the-glx_context-is-valid.patch
    + u_dri3-Check-for-dummyContext-to-see-if-the-glx_contex.patch
  * fdo#92850 - Segfault loading War Thunder
  * fdo#93767 - Glitches with soft shadows and MSAA in Knights of the Old Republic 2
  * fdo#94955 - Uninitialized variables leads to random segfaults (valgrind log,
  apitrace attached)
  * fdo#94994 -  OSMesaGetProcAdress always fails on mangled OSMesa
  * fdo#95026 - Alien Isolation segfault after initial loading screen/video
  * fdo#95133 - X-COM Enemy Within crashes when entering tactical mission with Bonaire
  * fdo#95164 - GLSL compiler (linker I think) emits assertion upon call to
  glAttachShader
  * fdo#95251 - vdpau decoder capabilities: not supported
  * radeon/uvd: alignment fix for decode message buffer
  * st/mesa: fix sampler view leak in st_DrawAtlasBitmaps()
  * gallium/util: initialize pipe_framebuffer_state to zeros
  * dri: Fix robust context creation via EGL attribute
  * dri2: Check for dummyContext to see if the glx_context is valid
  * cherry-ignore: remove duplicate commit
  * cherry-ignore: ignore the GetSamplerParameterIuiv{EXT,OES} fixups
  * vc4: Fix subimage accesses to LT textures.
  * vc4: Add support for rendering to cube map surfaces.
  * vc4: Fix tests for format supported with nr_samples == 1.
  * vc4: Make sure we recompile when sample_mask changes.
  * glapi: fix _glapi_get_proc_address() for mangled function names
  * nvc0: fix retrieving query results into buffer for timestamps
  * nouveau/video: properly detect the decoder class for availability checks
  * i965/fs: Properly report regs_written from SAMPLEINFO
  * egl/x11: authenticate before doing chipset id ioctls
  * winsys/sw/xlib: use correct free function for xlib_dt-&gt;data
  * i965: Fix clear code for ignoring colormask for XRGB formats on Gen9+.
  * glsl: Convert lower_vec_index_to_swizzle to a rvalue visitor.
  * glsl: Lower vector_extracts to swizzles after lower_vector_derefs.
  * radeon/uvd: fix tonga feedback buffer size
  * st/mesa: fix blit-based GetTexImage for non-finalized textures
  * gallium/radeon: handle failure when mapping staging buffer
  * st/glsl_to_tgsi: reduce stack explosion in recursive expression visitor
  * gallium/radeon: fix crash in r600_set_streamout_targets
  * radeonsi: correct NULL-pointer check in si_upload_const_buffer
  * radeonsi: work around an MSAA fast stencil clear problem
  * r600g/radeonsi: send endian info to format translation functions
  * r600g: set endianess of 16/32-bit buffers according to do_endian_swap
  * r600g: use do_endian_swap in color swapping functions
  * r600g: use do_endian_swap in texture swapping function
  * r600g: fix and optimize tgsi_cmp when using ABS and NEG modifier
  * llvmpipe: (trivial) initialize src1_alpha var to NULL
  * gallivm: fix bogus argument order to lp_build_sample_mipmap function
  * gallivm: make sampling more robust against bogus coordinates
  * gk110/ir: do not overwrite def value with zero for EXCH ops
  * gk110/ir: make use of IMUL32I for all immediates
  * nvc0/ir: fix wrong emission of (a OP b) OP c
  * gk110/ir: add emission for (a OP b) OP c
  * nvc0: reduce GL_MAX_3D_TEXTURE_SIZE to 2048 on Kepler+
  * st/glsl_to_tgsi: fix potential crash when allocating temporaries
  * dri3: Check for dummyContext to see if the glx_context is valid
  * i965/blorp/gen7: Prepare re-using for gen8
  * i965/blorp: Use 8k chunk size for urb allocation
  * tgsi: initialize stack allocated struct
  * winsys/sw/dri: use correct free function for dri_sw_dt-&gt;data
  * android: enable dlopen() on all architectures
* Thu Apr 21 2016 sndirsch@suse.com
- u_dri3-Check-for-dummyContext-to-see-if-the-glx_contex.patch
  * dri3: Check for dummyContext to see if the glx_context is valid
    According to the comments in src/glx/glxcurrent.c
    __glXGetCurrentContext() always returns a valid pointer. If no
    context is made current, it will contain dummyContext. Thus a
    test for NULL will always fail.
* Sun Apr 17 2016 mimi.vx@gmail.com
- update to 11.2.1
  * It fixes crashes in VAAPI, some build problems in Nine has been addressed,
    adds a drirc workaround for Warsow and resolves issues in the nouveau,
    radeonsi and i965 drivers.
  * fdo#93962 ES2-CTS.gtf.GL2FixedTests.scissor.scissor - segfault/asserts
* Mon Apr  4 2016 mimi.vx@gmail.com
- update to 11.2.0
- dropped U_clover-Fix-build-against-LLVM-3.8.patch
- dropped U_llvmpipe-Do-not-use-barriers-if-not-using-threads.patch
- New Features:
  * GL_ARB_arrays_of_arrays on all gallium drivers that provide GLSL 1.30
  * GL_ARB_base_instance on freedreno/a4xx
  * GL_ARB_compute_shader on i965
  * GL_ARB_copy_image on r600
  * GL_ARB_indirect_parameters on nvc0
  * GL_ARB_query_buffer_object on nvc0
  * GL_ARB_shader_atomic_counters on nvc0
  * GL_ARB_shader_draw_parameters on i965, nvc0
  * GL_ARB_shader_storage_buffer_object on nvc0
  * GL_ARB_tessellation_shader on i965 and r600 (evergreen/cayman only)
  * GL_ARB_texture_buffer_object_rgb32 on freedreno/a4xx
  * GL_ARB_texture_buffer_range on freedreno/a4xx
  * GL_ARB_texture_query_lod on freedreno/a4xx
  * GL_ARB_texture_rgb10_a2ui on freedreno/a4xx
  * GL_ARB_texture_view on freedreno/a4xx
  * GL_ARB_vertex_type_10f_11f_11f_rev on freedreno/a4xx
  * GL_KHR_texture_compression_astc_ldr on freedreno/a4xx
  * GL_AMD_performance_monitor on radeonsi (CIK+ only)
  * GL_ATI_meminfo on r600, radeonsi
  * GL_NVX_gpu_memory_info on r600, radeonsi
  * New OSMesaCreateContextAttribs() function (for creating core profile contexts)
  + Many bugfixes, for more info see relnotes/11.2.0.html
* Wed Mar 16 2016 eich@suse.com
- n_Define-GLAPIVAR-separate-from-GLAPI.patch:
  Add separate definition GLAPIVAR as GLAPI
  doesn't have the an 'extern' for some compiler
  versions. This is needed for GLw (bsc#970725).
* Wed Mar 16 2016 sndirsch@suse.com
- U_llvmpipe-Do-not-use-barriers-if-not-using-threads.patch
  * llvmpipe: Do not use barriers if not using threads; triggers
    on single cpu machines (like KVM in openQA) with gcc6 and
    latest glibc(bnc#971350)
* Mon Mar 14 2016 dmueller@suse.com
- enable llvmpipe for aarch64 (fate#320649)
* Thu Feb 11 2016 mimi.vx@gmail.com
-  update to 11.1.2
  * Bugfix release:
  + fdo#93648 - Random lines being rendered when playing Dolphin (geometry shaders
    elated, w/ apitrace)
  + fdo#93650 - GL_ARB_separate_shader_objects is buggy (PCSX2)
  + fdo#93717 - Meta mipmap generation can corrupt texture state
  + fdo#93722 - Segfault when compiling shader with a subroutine that takes a parameter
  + fdo#93731 - glUniformSubroutinesuiv segfaults when subroutine uniform is bound
    to a specific location
  + fdo#93761 - A conditional discard in a fragment shader causes no depth
    writing at all
  + Some bugfixes in i965,nv50,radeonsi,r600g,vc4 drivers
* Thu Jan 28 2016 idonmez@suse.com
- Add U_clover-Fix-build-against-LLVM-3.8.patch to fix build
  against llvm 3.8
* Wed Jan 20 2016 eich@suse.com
- u_dri2-Check-for-dummyContext-to-see-if-the-glx_context-is-valid.patch
  Check for dummyContext to see if the glx_context is valid (boo#962609).
* Wed Jan 20 2016 sndirsch@suse.com
- n_VDPAU-XVMC-libs-Replace-hardlinks-with-copies.patch
  * Since these are packaged separately in (open)SUSE anyway, one
    can use copies as well. This makes debug packages possible
    again. (bnc #962609)
* Wed Jan 13 2016 mimi.vx@gmail.com
- update to 11.1.1
  * Bugfix release and adding KB Lake PCI id's
  + fdo#91806 - configure does not test whether assembler supports sse4.1
  + fdo#92229 - [APITRACE] SOMA have serious graphical errors
  + fdo#92233 - Unigine Heaven 4.0 silhuette run
  + fdo#93004 - Guild Wars 2 crash on nouveau DX11 cards
  + fdo#93215 - [Regression bisected] Ogles1conform Automatic mipmap
    generation test is fail
  + fdo#93257 - [SKL, bisected] ASTC dEQP tests segfault
  + fixes for r600,nv*,glx,glsl,radeonsi and i965
* Wed Jan  6 2016 schwab@suse.de
- Enable swrast gallium driver on s390/aarch64
- Exclude Mesa-libva on s390/s390x/aarch64
* Sun Dec 20 2015 jimmy@boombatower.com
- Apply patch: st/va: hardlink driver instances to
  gallium_drv_video.so
  + u_st-va-hardlink-driver-instances-to-gallium_drv_video.patch
* Thu Dec 17 2015 jimmy@boombatower.com
- Add Mesa-libva.
* Tue Dec 15 2015 mimi.vx@gmail.com
- update to 11.1.0, new stable release
  * New features:
  + Note: some of the new features are only available with certain drivers.
  + OpenGL 3.1 support on freedreno (a3xx, a4xx)
  + OpenGL 3.3 support for VMware guest VM driver (supported by Workstation 12
    and Fusion 8).
  + GL_AMD_performance_monitor on nv50
  + GL_ARB_arrays_of_arrays on i965
  + GL_ARB_blend_func_extended on freedreno (a3xx)
  + GL_ARB_clear_texture on nv50, nvc0
  + GL_ARB_clip_control on freedreno/a4xx
  + GL_ARB_copy_image on nv50, nvc0, radeonsi
  + GL_ARB_depth_clamp on freedreno/a4xx
  + GL_ARB_fragment_layer_viewport on i965 (gen6+)
  + GL_ARB_gpu_shader_fp64 on r600 for Cypress/Cayman/Aruba chips
  + GL_ARB_gpu_shader5 on r600 for Evergreen and later chips
  + GL_ARB_seamless_cubemap_per_texture on freedreno/a4xx
  + GL_ARB_shader_clock on i965 (gen7+)
  + GL_ARB_shader_stencil_export on i965 (gen9+)
  + GL_ARB_shader_storage_buffer_object on i965
  + GL_ARB_shader_texture_image_samples on i965, nv50, nvc0, r600, radeonsi
  + GL_ARB_texture_barrier / GL_NV_texture_barrier on i965
  + GL_ARB_texture_buffer_range on freedreno/a3xx
  + GL_ARB_texture_compression_bptc on freedreno/a4xx
  + GL_ARB_texture_query_lod on softpipe
  + GL_ARB_texture_view on radeonsi and r600 (for evergeen and newer)
  + GL_ARB_vertex_type_2_10_10_10_rev on freedreno (a3xx, a4xx)
  + GL_EXT_blend_func_extended on all drivers that support the ARB version
  + GL_EXT_buffer_storage implemented for when ES 3.1 support is gained
  + GL_EXT_draw_elements_base_vertex on all drivers
  + GL_EXT_texture_compression_rgtc / latc on freedreno (a3xx & a4xx)
  + GL_KHR_debug (GLES)
  + GL_NV_conditional_render on freedreno
  + GL_OES_draw_elements_base_vertex on all drivers
  + EGL_KHR_create_context on softpipe, llvmpipe
  + EGL_KHR_gl_colorspace on softpipe, llvmpipe
  + new virgl gallium driver for qemu virtio-gpu
  + 16x multisampling on i965 (gen9+)
  + GL_EXT_shader_samples_identical on i965.
  * +many bugfixes, please see relnotes
* Wed Dec  9 2015 mimi.vx@gmail.com
- Update to version 11.0.7
    + bugfixes release for bugs found since 11.0.6
    fdo#90348 - Spilling failure of b96 merged value
    fdo#92363 - [BSW/BDW] ogles1conform Gets test fails
    fdo#92438 - Segfault in pushbuf_kref when running the android
    emulator (qemu) on nv50
    fdo#93110 - [NVE4] textureSize() and textureQueryLevels() uses a texture
    bound during the previous draw call
    fdo#93126> - wrongly claim supporting GL_EXT_texture_rg
    + plus fixes for r600g,llvmpipe,i955,egl,gles2
* Tue Dec  1 2015 jimmy@boombatower.com
- Add Mesa-libOpenCL.
* Sun Nov 22 2015 zaitor@opensuse.org
- Update to version 11.0.6:
  + This release brings driver fixes for i965, r600, radeonsi,
    nouveau, vc4, and llvmpipe including a serious regression for
    r100/r200 era hardware.
  + Additional patches cover glsl, nir, mesa/meta and VC-1
    decoding.
* Wed Nov 11 2015 mimi.vx@gmail.com
- update to 11.0.5
  * With this release we have some driver patches for i965 and nouveau, a couple
    of llvm 3.7 related fixes and a some bugfixes in the VA state-tracker.
  * Additionally we have a few new PCI ids for i965 and radeonsi.
* Sun Oct 25 2015 mimi.vx@gmail.com
- update to 11.0.4
  * bug fix release which fixes bugs found since the 11.0.3 release
  * droped patches - merged by upstream:
    U_gallium-add-PIPE_SHADER_CAP_MAX_UNROLL_ITERATIONS_HI.patch
    U_i965-Remove-early-release-of-DRI2-miptree.patch
* Thu Oct 22 2015 sndirsch@suse.com
- U_gallium-add-PIPE_SHADER_CAP_MAX_UNROLL_ITERATIONS_HI.patch
  * This avoids a serious r600g bug leading to a GPU hang (bnc#951298)
* Tue Oct 20 2015 sndirsch@suse.com
- Update to 11.0.3
  * bug fix release which fixes bugs found since the 11.0.2 release
* Thu Oct  1 2015 sndirsch@suse.com
- Update to 11.0.2
  * This is a emergency release which covers the final dEQP
    regressions introduced in the 11.0 development cycle.
* Wed Sep 30 2015 jslaby@suse.com
- update upstream status:
  * remove n_i965-Remove-early-release-of-DRI2-miptree.patch
  * add U_i965-Remove-early-release-of-DRI2-miptree.patch
* Sat Sep 26 2015 mpluskal@suse.com
- Update to 11.0.1
  * i965/vec4: Fix saturation errors when coalescing registers
  * i965/vec4_nir: Load constants as integers
  * meta: Abort meta pbo path if TexSubImage need signed unsigned
    conversion
  * docs: add sha256 checksums for 11.0.0
  * Update version to 11.0.1
  * docs: add release notes for 11.0.1
  * mesa: Fix GL_FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE for default
    framebuffer.
  * t_dd_dmatmp: Make "count" actually be the count
  * t_dd_dmatmp: Clean up improper code formatting from previous
    patch
  * t_dd_dmatmp: Use '& 3' instead of '%% 4' everywhere
  * t_dd_dmatmp: Pull out common 'count -= count & 3' code
  * t_dd_dmatmp: Use addition instead of subtraction in loop
    bounds
  * st/mesa: avoid integer overflows with buffers >= 512MB
  * nv50, nvc0: fix max texture buffer size to 128M elements
  * freedreno/a3xx: fix blending of L8 format
  * nv50,nvc0: detect underlying resource changes and update tic
  * nv50,nvc0: flush texture cache in presence of coherent bufs
  * radeonsi: load fmask ptr relative to the resources array
  * nir: Fix a bunch of ralloc parenting errors
  * i965/vec4: Don't reswizzle hardware registers
  * configure.ac: Add support to enable read-only text segment on
    x86.
  * gbm: convert gbm bo format to fourcc format on dma-buf import
  * mesa: fix errors when reading depth with glReadPixels
  * i965: fix textureGrad for cubemaps
  * mesa: Fix texture compression on big-endian systems
* Mon Sep 14 2015 jslaby@suse.com
- add n_i965-Remove-early-release-of-DRI2-miptree.patch (bnc#945444)
* Mon Sep 14 2015 sndirsch@suse.com
- marked Mesa.keyring and mesa-11.0.0.tar.xz.sig as source in
  specfile in order to make factory checkin policy happy
* Sat Sep 12 2015 mimi.vx@gmail.com
- Update to version 11.0.0
  * Mesa 11.0 brings core Mesa support for OpenGL 4.2, RadeonSI and Nouveau NVC0
  OpenGL 4.1 support (the other hardware drivers remain at OpenGL 3.3), AMDGPU
  kernel driver support along with initial R9 Fury/Fiji support, EGL 1.5 support,
  ongoing OpenGL ES 3.1 work, OpenCL compute image support, HEVC video decode
  support for RadeonSI via VDPAU, OpenGL ES 3.0 for Freedreno, and many fixes.
  + drop U_mesa-llvm37-rename-r600-to-amdgpu.patch and U_mesa-llvm37.patch
* Fri Sep 11 2015 mimi.vx@gmail.com
- Update to version 10.6.7
  + add gpg verification of source package
  * fdo#90751 Revert "i965: Momentarily pretend to support
  ARB_texture_stencil8 for blits."
  * mesa/teximage: use correct extension for accept stencil texture.
* Mon Sep  7 2015 zaitor@opensuse.org
- Update to version 10.6.6:
  * This release includes patches for mesa core, i965 (regression
    fixes), r600 (assertions and crash fixes in the sb backend),
    radeonsi (workaround for GPU hang in Unigine Heaven) and
    nouveau (piglit tests).
- Replace libXvMC-devel and libexpat-devel for pkgconfig(xvmc) and
  pkgconfig(expat) BuildRequires.
* Mon Sep  7 2015 alarrosa@suse.com
- Add U_mesa-llvm37-rename-r600-to-amdgpu.patch to fix build with llvm 3.7
  due to rename of llvm target R600 to AMDGPU
* Sat Sep  5 2015 idonmez@suse.com
- Add U_mesa-llvm37.patch to fix build with llvm 3.7
* Sat Aug 22 2015 zaitor@opensuse.org
- Update to version 10.6.5:
  * Apart from the usual nouveau, i965 and radeon driver fixes,
    this time around we have a nouveau_vieux fix for a regression
    introduced with mesa 10.6.0 and a few even older big endian
    related bug-fixes.
- Replace libvdpau-devel for pkgconfig(vdpau) BuildRequires.
* Wed Aug 12 2015 sndirsch@suse.com
- update to 10.6.4
  * In this release we have a few GL specific fixes (in both dri
    drivers and the EGL loader), an updated mesa.icd file and a
    crashfix for the standalone glcpp tool.
* Wed Jul 29 2015 mimi.vx@gmail.com
- update to 10.6.3
  * fdo#90728 - dvd playback with vlc and vdpau causes segmentation fault
  * fdo#91337 - OSMesaGetProcAdress(&quot;OSMesaPixelStore&quot;) returns nil
  * osmesa: fix OSMesaPixelsStore typo
  * vl: cleanup video buffer private when the decoder is destroyed
  * st/vdpau: fix mixer size checks
  * auxiliary/vl: use the correct screen index
  * i965/gen9: Use custom MOCS entries set up by the kernel.
  * nv50, nvc0: enable at least one color RT if alphatest is enabled
  * nvc0/ir: fix txq on indirect samplers
  * nvc0/ir: don't worry about sampler in txq handling
  * gm107/ir: fix indirect txq emission
  * nv50: fix max level clamping on G80
  * program: Allow redundant OPTION ARB_fog_* directives.
  * xa: don't leak fences
* Sun Jul 12 2015 mimi.vx@gmail.com
- update to 10.6.2
  * fdo#73528 - Deferred lighting in Second Life causes system hiccups and screen flickering
  * fdo#80500 - Flickering shadows in unreleased title trace
  * fdo#82186 - [r600g] BARTS GPU lockup with minecraft shaders
  * fdo#84225 - Allow constant-index-expression sampler array indexing with GLSL-ES < 300
  * fdo#90537 - radeonsi bo/va conflict on RADEON_GEM_VA (rscreen->ws->buffer_from_handle returns NULL)
  * fdo#90873 - Kernel hang, TearFree On, Mate desktop environment
  * fdo#91022 - [g45 g965 bisected] assertions generated from textureGrad cube samplers fix
  * fdo#91047 - [SNB Bisected] Messed up Fog in Super Smash Bros. Melee in Dolphin
  * fdo#91056 - The Bard's Tale (2005, native) has rendering issues
  * fdo#91117 - Nimbus (running in wine) has rendering issues, objects are semi-transparent
  * fdo#91124 - Civilization V (in Wine) has rendering issues: text missing, menu bar corrupted
  * fdo#91173 - Oddworld: Stranger's Wrath HD: disfigured models in wrong colors
  * fdo#91226 - Crash in glLinkProgram (NEW)
  * fdo#91231 - [NV92] Psychonauts (native) segfaults on start when DRI3 enabled
  * loader: Look for any version of currently linked libudev.so
  * nv50/ir: propagate modifier to right arg when const-folding mad
  * nv50/ir: fix emission of address reg in 3rd source
  * nv50/ir: copy joinAt when splitting both before and after
  * mesa: reset the source packing when creating temp transfer image
  * nv50/ir: don't emit src2 in immediate form
  * mesa/prog: relative offsets into constbufs are not constant
  * nv50/ir: UCMP arguments are float, so make sure modifiers are applied
  * nvc0: turn sample counts off during blit
  * i965/fs: Fix ir_txs in emit_texture_gen4_simd16().
  * i965: Reserve more batch space to accomodate Gen6 perfmonitors.
  * i965/vs: Fix matNxM vertex attributes where M != 4.
  * Revert "glsl: clone inputs and outputs during linking"
  * Revert "i965: Delete linked GLSL IR when using NIR."
  * r600g: disable single-sample fast color clear due to hangs
  * radeonsi: fix a hang with DrawTransformFeedback on 4 SE chips
  * st/dri: don't set PIPE_BIND_SCANOUT for MSAA surfaces
  * nouveau: Use dup fd as key in drm-winsys hash table to fix ZaphodHeads.
  * winsys/radeon: Use dup fd as key in drm-winsys hash table to fix ZaphodHeads.
  * i965/fs: Don't mess up stride for uniform integer multiplication.
  * winsys/radeon: Unmap GPU VM address range when destroying BO
  * meta: Only change and restore viewport 0 in mesa meta mode
  * i965: allocate at least 1 BLEND_STATE element
  * i965/skl: Set the pulls bary bit in 3DSTATE_PS_EXTRA
  * glsl: Add missing check for whether an expression is an add operation
  * glsl: Make sure not to dereference NULL
  * i965: Don't try to print the GLSL IR if it has been freed
  * glsl: clone inputs and outputs during linking
  * i965: Delete linked GLSL IR when using NIR.
  * glsl: Allow dynamic sampler array indexing with GLSL ES < 3.00
  * mesa/glsl: new compiler option EmitNoIndirectSampler
  * i965: use EmitNoIndirectSampler for gen < 7
  * i915: use EmitNoIndirectSampler
  * mesa/st: use EmitNoIndirectSampler if !ARB_gpu_shader5
  * glsl: validate sampler array indexing for 'constant-index-expression'
* Mon Jun 29 2015 mimi.vx@gmail.com
- adjust libdrm dependencies
* Mon Jun 29 2015 sndirsch@suse.com
- Update to version 10.6.1
  * This release includes core mesa and glsl patches (amonst which
    a Dota2 Reborn bugfix) affecting all dri drivers, nouveau specific
    fixes and a selection of shared-glapi commits - from build fixes, to
    ones ensuring that the dri modules can be loaded.
* Tue Jun 23 2015 sndirsch@suse.com
- n_Fixed-build-against-wayland-1.2.1.patch
  * required to fix build with wayland on openSUSE 13.1
* Mon Jun 15 2015 tobias.johannes.klausmann@mni.thm.de
- Update to version 10.6.0:
- New GL/EGL Features:
  + GL_AMD_pinned_memory on r600, radeonsi
  + GL_ARB_clip_control on i965
  + GL_ARB_depth_buffer_float on freedreno
  + GL_ARB_depth_clamp on freedreno
  + GL_ARB_direct_state_access on all drivers for Core GL contexts.
  + GL_ARB_draw_indirect, GL_ARB_multi_draw_indirect on r600
  + GL_ARB_draw_instanced on freedreno
  + GL_ARB_gpu_shader_fp64 on nvc0, softpipe
  + GL_ARB_gpu_shader5 on i965/gen8+
  + GL_ARB_instanced_arrays on freedreno
  + GL_ARB_pipeline_statistics_query on i965, nv50, nvc0, r600, radeonsi, softpipe
  + GL_ARB_program_interface_query (all drivers)
  + GL_ARB_texture_stencil8 on nv50, nvc0, r600, radeonsi, softpipe
  + GL_ARB_texture_view on llvmpipe, softpipe
  + GL_ARB_uniform_buffer_object on freedreno
  + GL_ARB_vertex_attrib_64bit on nvc0, softpipe
  + GL_ARB_viewport_array, GL_AMD_vertex_shader_viewport_index on i965/gen6
  + GL_EXT_draw_buffers2 on freedreno
  + GL_OES_EGL_sync on all drivers
  + EGL_KHR_fence_sync on i965, freedreno, nv50, nvc0, r600, radeonsi
  + EGL_KHR_wait_sync on i965, freedreno, nv50, nvc0, r600, radeonsi
  + EGL_KHR_cl_event2 on freedreno, nv50, nvc0, r600, radeonsi
  + GL_AMD_performance_monitor on nvc0
- Changes to package:
  + add --enable-shader-cache to configure options
  + remove Patch100: U_0001_gallium_include_util_macros.patch
  + remove Patch101: U_0002_st_nine_mark_end_of_non_void_function_unreachable.patch
  + remove Patch102: U_0003_fix_build_after_macro_include.patch
* Mon Jun  8 2015 zaitor@opensuse.org
- Update to version 10.5.7:
  + i965: Emit 3DSTATE_MULTISAMPLE before WM_HZ_OP (gen8+)
  + docs: Add sha256sums for the 10.5.6 release
  + get-pick-list.sh: Require explicit "10.5" for nominating stable patches
  + cherry-ignore: add clover build fix not applicable for 10.5
  + Add release notes for the 10.5.7 release
  + nvc0/ir: set ftz when sources are floats, not just destinations
  + nv50/ir: guess that the constant offset is the starting slot of array
  + nvc0/ir: LOAD's can't be used for shader inputs
  + nvc0: a geometry shader can have up to 1024 vertices output
  + nv50/ir: avoid messing up arg1 of PFETCH
  + nv30: don't leak fragprog consts
  + nv30: avoid leaking render state and draw shaders
  + nv30: fix clip plane uploads and enable changes
  + nv30/draw: avoid leaving stale pointers in draw state
  + nv30/draw: draw expects constbuf size in bytes, not vec4 units
  + st/mesa: don't leak glsl_to_tgsi object on link failure
  + glsl: avoid leaking linked gl_shader when there's a late linker error
  + nv30/draw: fix indexed draws with swtnl path and a resource index buffer
  + nv30/draw: only use the DMA1 object (GART) if the bo is not in VRAM
  + nv30/draw: allocate vertex buffers in gart
  + nv30/draw: switch varying hookup logic to know about texcoords
  + nv30: falling back to draw path for edgeflag does no good
  + nv30: avoid doing extra work on clear and hitting unexpected states
  + i965/fs: Fix implied_mrf_writes for scratch writes
  + st/dri: fix postprocessing crash when there's no depth buffer
* Mon May 25 2015 mimi.vx@gmail.com
- update to 10.5.6
  * fdo#86792 - [NVC0] Portal 2 Crashes in Wi* ne
  * fdo#90350 - [G96] Portal's portal are incorrectly rendered
  * fdo#90363 - [nv50] HW state is not reset correctly when using a new GL context
  * radeonsi: add new bonaire pci id
  * egl/wayland: properly destroy wayland objects
  * glx/dri3: Add additional check for gpu offloading case
  * egl/main: fix EGL_KHR_get_all_proc_addresses
  * targets/osmesa: drop the -module tag from LDFLAGS
  * clover: Refactor event::trigger and ::abort to prevent deadlock and reentrancy issues.
  * clover: Wrap event::_status in a method to prevent unlocked access.<
  * clover: Implement locking of the wait_count, _chain and _status members of event.
  * i965: Fix PBO cache coherency issue after _mesa_meta_pbo_GetTexSubImage().
  * main: Require that the texture exists in framebuffer_texture
  * mesa: Generate GL_INVALID_VALUE in framebuffer_texture when layer <0
  * nv50/ir: only propagate saturate up if some actual folding took place
  * nv50: keep track of PGRAPH state in nv50_screen
  * nvc0: keep track of PGRAPH state in nvc0_screen
  * nvc0: reset the instanced elements state when doing blit using 3d engine
  * nv50/ir: only enable mul saturate on G200+
  * st/mesa: make sure to create a "clean" bool when doing i2b
  * nvc0: switch mechanism for shader eviction to be a while loop
  * swrast: Build fix for darwin
  * main: Fix an error generated by FramebufferTexture</li>
  * main: Complete error conditions for glInvalidate*Framebuffer.
  * main: glGetIntegeri_v fails for GL_VERTEX_BINDING_STRIDE
  * freedreno: enable a306
  * freedreno: fix bug in tile/slot calculation
  * draw: (trivial) fix out-of-bounds vector initialization
  * mesa: fix shininess check for ffvertex_prog v2
  * clover: Add a mutex to guard queue::queued_events
  * clover: Fix a bug with multi-threaded events v2
* Sat May 16 2015 mimi.vx@gmail.com
- Update to 10.5.5
  * fdo#88521 - GLBenchmark 2.7 TRex renders with artifacts on Gen8 with !UXA
  * fdo#89455 - [NVC0/Gallium] Unigine Heaven black and white boxes
  * fdo#89689 - [Regression] Weston on DRM backend won't start with new version of mesa
  * fdo#90130 - gl_PrimitiveId seems to reset at 340
  * i965: Add XRGB8888 format to intel_screen_make_configs
  * r300: do not link against libdrm_intel
  * nvc0/ir: flush denorms to zero in non-compute shaders
  * gk110/ir: fix set with a register dest to not auto-set the abs flag
  * nvc0/ir: fix predicated PFETCH emission
  * nv50/ir: fix asFlow() const helper for OP_JOIN
  * i965: Make intel_emit_linear_blit handle Gen8+ alignment restrictions.
  * i965: Disallow linear blits that are not cacheline aligned.
  * draw: fix prim ids when there's no gs
* Mon May 11 2015 fstrba@suse.com
- BuildIgnore python so that it is not sucked in by coincidence
  * The python-base provides enough python functionalities
    necessary for build.
* Mon Apr 27 2015 sndirsch@suse.com
- Update to 10.5.4
  * This release includes fixes for the mesa state-tracker used by
    all the gallium drivers, a drirc workaround for Second Life,
    plus i965 fixes. For the Android users out there, this release
    includes many compilation fixes with more to come shortly.
* Thu Apr 16 2015 mimi.vx@gmail.com
- Update to 10.5.3
  + fdo#83962 - [HSW/BYT]Piglit spec_ARB_gpu_shader5_arb_gpu_shader5-emitstreamvertex_nodraw fails
  + fdo#89679 - [NV50] Portal/Half-Life 2 will not start (native Steam)
  + fdo#89746 - Mesa and LLVM 3.6+ break opengl for genymotion
  + fdo#89754 - vertexAttrib fails WebGL Conformance test with mesa drivers
  + fdo#89758 - pow WebGL Conformance test with mesa drivers
  + fdo#89759 - WebGL OGL ES GLSL conformance test with mesa drivers fails
  + fdo#89905 - scons build broken on 10.5.2 due to activated vega st
  + st_glsl_to_tgsi: only do mov copy propagation on temps (v2)
  + xmlpool: don't forget to ship the MOS
  + configure.ac: error out if python/mako is not found when required
  + dist: add the VG depedencies into the tarball
  + i965: Do not render primitives in non-zero streams then TF is disabled
  + st/mesa: update arrays when the current attrib has been updated
  + nv50/ir: take postFactor into account when doing peephole optimizations
  + nv50/ir/gk110: fix offset flag position for TXD opcode
  + freedreno/a3xx: fix 3d texture layout
  + freedreno/a3xx: point size should not be divided by 2
  + nv50: allocate more offset space for occlusion queries
  + nv50,nvc0: limit the y-tiling of 3d textures to the first level's tiling
  + i965: Fix instanced geometry shaders on Gen8+.
  + i965: Add forgotten multi-stream code to Gen8 SOL state.
  + nouveau: synchronize "scratch runout" destruction with the command stream
  + radeonsi: Cache LLVMTargetMachineRef in context instead of in screen
  + clover: Return CL_BUILD_ERROR for CL_PROGRAM_BUILD_STATUS when compilation fails v2
  + i965: Fix URB size for CHV
* Sun Mar 29 2015 mimi.vx@gmail.com
- Update to  10.5.2
  + fdo#88534 - include/c11/threads_posix.h PTHREAD_MUTEX_RECURSIVE_NP not defined
  + fdo#89328 - python required to build Mesa release tarballs
  + fdo#89530 - FTBFS in loader: missing fstat
  + fdo#89590 - Crash in glLinkProgram with shaders with multiple constant arrays
  + fdo#89680 - Hard link exist in Mesa 10.5.1 sources
  + glsl: Generate link error for non-matching gl_FragCoord redeclarations
  + docs: Add sha256 sums for the 10.5.1 release
  + automake: add missing egl files to the tarball
  + st/egl: don't ship the dri2.c link at the tarball
  + loader: include <sys/stat.h> for non-sysfs builds
  + auxiliary/os: fix the android build - s/drm_munmap/os_munmap/
  + cherry-ignore: add commit non applicable for 10.5
  + c11/threads: Use PTHREAD_MUTEX_RECURSIVE by default
  + i965: Set nr_params to the number of uniform components in the VS/GS path.
  + freedreno/a3xx: use the same layer size for all slices
  + freedreno: fix slice pitch calculations
  + radeonsi: increase coords array size for radeon_llvm_emit_prepare_cube_coords
  + glx: Handle out-of-sequence swap completion events correctly. (v2)
  + mapi: Make private copies of name strings provided by client.
  + freedreno: update generated headers
  + glsl: optimize (0 cmp x + y) into (-x cmp y).
  + glsl: fix names in lower_constant_arrays_to_uniforms
  + clover: Return 0 as storage size for local kernel args that are not set v2
* Sat Mar 14 2015 mimi.vx@gmail.com
- Update  to 10.5.1
  + fdo#79202 - valgrind errors in glsl-fs-uniform-array-loop-unroll.shader_test; random code generation
  + fdo#84613 - [G965, bisected] piglit regressions : glslparsertest.glsl2
  + fdo#86747 - Noise in Football Manager 2014 textures
  + fdo#86974 - INTEL_DEBUG=shader_time always asserts in fs_generator::generate_code() when Mesa is built with --enable-debug (= with asserts)
  + fdo#88246 - Commit 2881b12 causes 43 DrawElements test regressions
  + fdo#88793 - [BDW/BSW Bisected]Piglit/shaders_glsl-max-varyings fails
  + fdo#88883 - ir-a2xx.c: variable changed in assert statement
  + fdo#88885 - Transform feedback uses incorrect interleaving if a previous draw did not write gl_Position
  + fdo#89095 - [SNB/IVB/BYT Bisected]Webglc conformance/glsl/functions/glsl-function-mix-float.html fails
  + fdo#89156 - r300g: GL_COMPRESSED_RED_RGTC1 / ATI1N support broken
  + fdo#89224 - Incorrect rendering of Unigine Valley running in VM on VMware Workstation
  + fdo#89292 - [regression,bisected] incomplete screenshots in some cases
  + fdo#89311 - [regression, bisected] dEQP: Added entry points for glCompressedTextureSubImage*D.
  + fdo#89312 - [regression, bisected] main: Added entry points for CopyTextureSubImage*D. (d6b7c40cecfe01)
  + fdo#89315 - [HSW, regression, bisected] i965/fs: Emit MAD instructions when possible.
  + fdo#89317 - [HSW, regression, bisected] i965: Add LINTERP/CINTERP to can_do_cmod() (d91390634)
  + fdo#89416 - UE4Editor crash after load project
  + fdo#89430 - [g965][bisected] arb_copy_image-targets gl_texture* tests fail
  + i965/vec4: Don't lose the saturate modifier in copy propagation.
  + i965/gs: Check newly-generated GS-out VUE map against correct stage
  + egl: Take alpha bits into account when selecting GBM formats
  + docs: Add sha256 sums for the 10.5.0 release
  + egl/main: no longer export internal function
  + cherry-ignore: ignore a few more commits picked without -x
  + mapi: fix commit 90411b56f6bc817e229d8801ac0adad6d4e3fb7a
  + intel: fix EGLImage renderbuffer _BaseFormat
  + i965: Fix out-of-bounds accesses into pull_constant_loc array
  + i965/fs/nir: Use emit_math for nir_op_fpow
  + freedreno: move fb state copy after checking for size change
  + freedreno/ir3: fix array count returned by TXQ
  + freedreno/ir3: get the # of miplevels from getinfo
  + meta/TexSubImage: Stash everything other than PIXEL_TRANSFER/store in meta_begin
  + main/base_tex_format: Properly handle STENCIL_INDEX1/4/16
  + i965: Split Gen4-5 BlitFramebuffer code; prefer BLT over Meta.
  + glsl: Mark array access when copying to a temporary for the ?: operator.
  + i965/fs: Set force_writemask_all on shader_time instructions.
  + i965/fs: Set smear on shader_time diff register.
  + i965/fs: Make emit_shader_time_write return rather than emit.
  + i965/fs: Make get_timestamp() pass back the MOV rather than emitting it.
  + i965/fs: Make emit_shader_time_end() insert before EOT.
  + i965/fs: Don't issue FB writes for bound but unwritten color targets.
  + main: Fix target checking for CompressedTexSubImage*D.
  + main: Fix target checking for CopyTexSubImage*D.
  + gallium/auxiliary/indices: fix start param
  + r300g: fix RGTC1 and LATC1 SNORM formats
  + r300g: fix a crash when resolving into an sRGB texture
  + r300g: fix sRGB->sRGB blits
  + i965/vec4: Fix implementation of i2b.
  + mesa: Indent break statements and add a missing one.
  + mesa: Free memory allocated for luminance in readpixels.
  + mesa: Correct backwards NULL check.
  + i965: Consider scratch writes to have side effects.
  + i965/fs: Don't use backend_visitor::instructions after creating the CFG.
  + r300g: Use PATH_MAX instead of limiting ourselves to 100 chars.
  + r300g: Check return value of snprintf().
  + i965/fs: Don't propagate cmod to inst with different type.
  + i965: Tell intel_get_memcpy() which direction the memcpy() is going.
  + Revert SHA1 additions.
  + i965: Avoid applying negate to wrong MAD source.
  + meta: In pbo_{Get,}TexSubImage don't repeatedly rebind the source tex
  + Revert "common: Fix PBOs for 1D_ARRAY."
  + meta: Allow GL_UN/PACK_IMAGE_HEIGHT in _mesa_meta_pbo_Get/TexSubImage
  + meta: Fix the y offset for 1D_ARRAY in _mesa_meta_pbo_TexSubImage
  + freedreno/ir3: fix silly typo for binning pass shaders
  + freedreno/a2xx: fix increment in assert
  + freedreno/a4xx: bit of cleanup
  + freedreno: update generated headers
  + freedreno/a4xx: set PC_PRIM_VTX_CNTL.VAROUT properly
  + freedreno: update generated headers
  + freedreno/a4xx: aniso filtering
  + freedreno/ir3: fix up cat6 instruction encodings
  + freedreno/ir3: add support for memory (cat6) instructions
  + freedreno/ir3: handle flat bypass for a4xx
  + freedreno/ir3: fix failed assert in grouping
  + r300g: Fix the ATI1N swizzle (RGTC1 and LATC1)
* Sat Mar  7 2015 tobias.johannes.klausmann@mni.thm.de
- Update to version 10.5.0:
  + Initial support for the new Intel Skylake GPUs and Adreno 4xx
    GPUs.
  + Experimental EGL support for Haiku.
  + The new IR - NIR. A flat, typeless IR, supporting SSA.
  + GLX/DRI3 fixes and improvements.
  + A lot of preparation work for GL_ARB_direct_state_access.
  + The usual amount of piglit and drawElements Quality Program
    (dEQP) fixes.
  + Building mesa with GCC 4.1 or earlier is no longer supported.
  + The distribution tarball has been renamed and now contains all
    the generated sources.
- New GL features:
  + GL_ARB_framebuffer_sRGB on freedreno
  + GL_ARB_texture_rg on freedreno
  + GL_EXT_packed_float on freedreno
  + GL_EXT_polygon_offset_clamp on i965, nv50, nvc0, r600, radeonsi,
    llvmpipe
  + GL_EXT_texture_shared_exponent on freedreno
  + GL_EXT_texture_snorm on freedreno
- Changes to Package:
  + switch to xz compressed sources
  + remove Patch16: u_gallivm_Update_for_RTDyldMemoryManager_unique_ptr.patch
  + add Patch100: U_0001_gallium_include_util_macros.patch
  + add Patch101: U_0002_st_nine_mark_end_of_non_void_function_unreachable.patch
  + add Patch102: U_0003_fix_build_after_macro_include.patch
* Mon Mar  2 2015 idonmez@suse.com
- Add u_gallivm_Update_for_RTDyldMemoryManager_unique_ptr.patch to
  fix build with llvm 3.6 (fdo#86958)
* Tue Feb 24 2015 tobias.johannes.klausmann@mni.thm.de
- Fix file permissions for the Gallium Nine files
* Mon Feb 23 2015 sndirsch@suse.com
- specfile/baselibs.conf: Manually provide d3d library (bnc#918294)
* Tue Feb 10 2015 zaitor@opensuse.org
- Drop pkgconfig(libva) BuildRequires for now, as it introduces a
  build-cycle.
* Sun Feb  8 2015 zaitor@opensuse.org
- Update to version 10.4.4:
  + mesa: fix display list 8-byte alignment issue.
  + docs: Add sha256 sums for the 10.4.3 release.
  + egl: Pass the correct X visual depth to xcb_put_image().
  + glx/dri3: Request non-vsynced Present for swapinterval zero.
  + gallium/util: Don't use __builtin_clrsb in util_last_bit().
  + configure: Link against all LLVM targets when building clover.
  + st/osmesa: Fix osbuffer->textures indexing.
  + i965: Fix max_wm_threads for CHV.
  + Bugs fixed: fdo#88662, fdo#88930.
- Add pkgconfig(libva) BuildRequires: Build VA API support.
* Mon Feb  2 2015 sndirsch@suse.com
- baselibs.conf: enabled build of 32bit Mesa-libd3d package
  (bnc#910109)
* Thu Jan 29 2015 sndirsch@suse.com
- moved definition of Mesa-libd3d package above definition of
  libxatracker packages in order to fix version requires
* Wed Jan 28 2015 sndirsch@suse.com
- fixed Requires for libd3d-devel
* Tue Jan 27 2015 sndirsch@suse.com
- enabled build of Direct3D 9 (Gallium3D Nine) state tracker (bnc#910109)
- removed obsolete patch u_be_assert_include.patch, addressed by
  upstream commit 2a13ff9 "gallium/util: add missing u_debug include"
  (bnc#910109)
* Tue Jan 27 2015 schwab@suse.de
- Set xvmc_support also on ppc
* Sun Jan 25 2015 mimi.vx@gmail.com
- Version bump to 10.4.3 (bugfix release):
  * Bug 80568 - [gen4] GPU Crash During Google Chrome Operation
  * Bug 85367 - [gen4] GPU hang in glmark-es2
  * Bug 85696 - r600g+nine: Bioshock shader failure after 7b1c0cbc90d456384b0950ad21faa3c61a6b43ff
  * Bug 88219 - include/c11/threads_posix.h:197: undefined reference to `pthread_mutex_lock'
  * mesa: Fix clamping to -1.0 in snorm_to_float
  * glsl: Link glsl_test with pthreads library.
  * i965: Respect the no_8 flag on Gen6, not just Gen7+.
  * i965: Work around mysterious Gen4 GPU hangs with minimal state changes.
* Fri Jan 16 2015 tchvatal@suse.com
- Clean up with the spec-cleaner
- Drop obsolete obsoletes comming from fix for sle10
- Reduce llvm_r600 conditional as it is equal to ifarch x86 x86_64
- Put vdpau_radeon and vdpau_nouveau under same case as they have
  same requisites
- Fix empty post/postun warning
- Various other rpmlint issues silenced.
* Fri Jan 16 2015 tchvatal@suse.com
- Version bump to 10.4.2 (bugfix release):
  * Bug 85529 - Surfaces not drawn in Unvanquished
  * Bug 87619 - Changes to state such as render targets change fragment shader without marking it dirty.
  * Bug 87658 - [llvmpipe] SEGV in sse2_has_daz on ancient Pentium4-M
  * Bug 87913 - CPU cacheline size of 0 can be returned by CPUID leaf 0x80000006 in some virtual machines
  * i965: Use safer pointer arithmetic in intel_texsubimage_tiled_memcpy()
  * i965: Use safer pointer arithmetic in gather_oa_results()
  * Revert "r600g/sb: fix issues cause by GLSL switching to loops for switch"
  * r600g: fix regression since UCMP change
  * r600g/sb: implement r600 gpr index workaround. (v3.1)
  * docs: Add sha256 sums for the 10.4.1 release
  * Update version to 10.4.2
  * nv50,nvc0: set vertex id base to index_bias
  * nv50/ir: fix texture offsets in release builds
  * i965: Add missing BRW_NEW_*_PROG_DATA to texture/renderbuffer atoms.
  * i965: Fix start/base_vertex_location for >1 prims but !BRW_NEW_VERTICES.
  * gallium/util: make sure cache line size is not zero
  * glsl_to_tgsi: fix a bug in copy propagation
  * vbo: ignore primitive restart if FixedIndex is enabled in DrawArrays
  * st/mesa: fix GL_PRIMITIVE_RESTART_FIXED_INDEX
  * radeonsi: fix VertexID for OpenGL
  * radeonsi: Don't modify PA_SC_RASTER_CONFIG register value if rb_mask == 0
  * gallium/util: fix crash with daz detection on x86
  * nv50,nvc0: implement half_pixel_center
  * r600g/sb: fix issues with loops created for switch
- Use download url fully in Source line
* Sun Dec 14 2014 tobias.johannes.klausmann@mni.thm.de
- Update to version 10.4.0 (10.4 Final):
- New features:
  + GL_ARB_conditional_render_inverted on nv50
  + GL_ARB_sample_shading on r600
  + GL_ARB_texture_view on nv50, nvc0
  + GL_ARB_clip_control on nv50, nvc0, r300, r600, radeonsi, llvmpipe, softpipe
  + GL_KHR_context_flush_control on all drivers
- Changes:
  + Removed patch17: u_Suppress-any-libGL-.-warnings-when-LIBGL_DEBUG-is-se.patch
    This patch was upstreamed
  + Build without "--enable-gallium-egl"
    This buildoption was removed upstream
  + Add subpackage libvdpau_r300
* Sun Nov 16 2014 afaerber@suse.de
- Enable VideoCore IV (vc4) support for ARM
* Fri Nov 14 2014 tobias.johannes.klausmann@mni.thm.de
- Cleanup Spec:
  + smaller cleanups
  + Remove all traces of talloc, Mesa uses ralloc
* Fri Nov 14 2014 seanpwatson@live.com
- Update to 10.3.3
  + fdo#82921 layout(location=0) emits error
  >= MAX_UNIFORM_LOCATIONS due to integer underflow
  + fdo#83574 [llvmpipe] [softpipe] piglit
  arb_explicit_uniform_location-use-of-unused-loc regression
  + fdo#85454 Unigine Sanctuary with Wine crashes on Mesa Git
  + fdo#70410 egl-static/Makefile: linking fails with llvm >= 3.4
* Tue Nov  4 2014 seanpwatson@live.com
- Update to 10.3.2
  + (fdo#54372) GLX_INTEL_swap_event crashes driver when swapping
  window buffers
  + (fdo#81680) [r600g] Firefox crashes with hardware acceleration
  turned on
  + (fdo#84140) mplayer crashes playing some files using vdpau
  output
  + (fdo#84662) Long pauses with Unreal demo Elemental on R9270X
  since : Always flush the HDP cache before submitting a
    CS to the GPU
  + (fdo#85267) vlc crashes with vdpau (Radeon 3850HD) [r600]
* Thu Oct 30 2014 jengelh@inai.de
- Update descriptions and Requires for GLES3
* Sat Oct 25 2014 josua.mayer97@gmail.com
- add Mesa-devel-dri package:
  This way dri.pc will no longer pull in all of Mesa, just as
  packages requiring dri do not have to require Mesa-devel anymore
* Mon Oct 13 2014 seanpwatson@live.com
- Update to 10.3.1
  + [NVC0/Codegen] Shader compilation falis in spill logic
  + [SNB+ Bisected]Ogles3conform ES3-CTS.shaders.
    indexing.vector_subscript.vec3_static_loop_subscript_write_
    direct_read_vertex fails
  + [UBO] row_major layout ignored inside structures
  + [UBO] nested structures don't get appropriate padding
  + Glyphy demo throws unhandled Integer division by zero exception
  + [UBO] row_major layout partially ignored for arrays of structures
  + Big glamor regression in Xorg server 1.6.99.1 GIT: x11perf 1.5
    Test: PutImage XY 500x500 Square
* Thu Sep 25 2014 dvaleev@suse.com
- Fix ppc64 build (bnc#893275 bnc#871128)
  u_be_assert_include.patch
  Add ncurses-devel as build dependency to build with -ltinfo
- Enable llvm on ppc64le (llvm3.5 got ppc64le support)
- Enable shared on ppc64 and ppc64le
* Sat Sep 20 2014 tobias.johannes.klausmann@mni.thm.de
- Update to version 10.3.0 (10.3 Final):
- New features:
  + GL_ARB_ES3_compatibility on nv50, nvc0, r600, radeonsi, softpipe, llvmpipe
  + GL_ARB_clear_texture on i965
  + GL_ARB_compressed_texture_pixel_storage on all drivers
  + GL_ARB_conditional_render_inverted on i965, nvc0, softpipe, llvmpipe
  + GL_ARB_derivative_control on i965, nv50, nvc0, r600
  + GL_ARB_draw_indirect on nvc0, radeonsi
  + GL_ARB_explicit_uniform_location (all drivers that support GLSL)
  + GL_ARB_fragment_layer_viewport on nv50, nvc0, llvmpipe, r600
  + GL_ARB_gpu_shader5 on i965/gen7, nvc0
  + GL_ARB_multi_draw_indirect on nvc0, radeonsi
  + GL_ARB_sample_shading on radeonsi
  + GL_ARB_seamless_cubemap_per_texture on i965, llvmpipe, nvc0, r600, radeonsi, softpipe
  + GL_ARB_stencil_texturing on nv50, nvc0, r600, and radeonsi
  + GL_ARB_texture_barrier on nv50, nvc0, r300, r600, radeonsi
  + GL_ARB_texture_compression_bptc on i965/gen7+, nvc0, r600/evergreen+, radeonsi
  + GL_ARB_texture_cube_map_array on radeonsi
  + GL_ARB_texture_gather on r600, radeonsi
  + GL_ARB_texture_query_levels on nv50, nvc0, llvmpipe, r600, radeonsi, softpipe
  + GL_ARB_texture_query_lod on r600, radeonsi
  + GL_ARB_viewport_array on nvc0
  + GL_AMD_vertex_shader_viewport_index on i965/gen7+, r600
  + GL_OES_compressed_ETC1_RGB8_texture on nv30, nv50, nvc0, r300, r600, radeonsi, softpipe, llvmpipe
  + GLX_MESA_query_renderer on nv30, nv50, nvc0, r300, r600, radeonsi, softpipe, llvmpipe
  + A new software rasterizer driver (kms_swrast_dri.so) that works with DRM drivers that don't have a full-fledged GEM (such as qxl or simpledrm)
- Changes:
  Building of gallium-pipe disabled for now by upstream, see:
  http://cgit.freedesktop.org/mesa/mesa/commit/?h=10.3&id=07426ad1029c3505b809dc9eec104007fb623983
  Nevertheless keep it around as it may get enabled again.
* Mon Aug 25 2014 sndirsch@suse.com
- Update to version 10.3.0-RC1
  * Mesa 10.3 brings many performance improvements, more
    OpenGL 4.x functionality, the VC4 Gallium3D driver,
    and much more.
  * supersedes U_mesa-glx-Reduce-error-log-level.patch
* Sun Aug 24 2014 dvlaeev@suse.com
- Package vdpau_r600 for ppc64le as well (bnc#893275)
* Fri Aug 22 2014 sndirsch@suse.com
- u_Suppress-any-libGL-.-warnings-when-LIBGL_DEBUG-is-se.patch
  Suppress any "libGL:..." warnings when LIBGL_DEBUG == "quiet"
  (bnc#892896)
* Fri Aug 15 2014 sndirsch@suse.com
- no longer add /usr/%%{_lib}/dri/updates to DRI driver search path
  (FATE#317822)
* Thu Aug  7 2014 sndirsch@suse.com
- Update to version 10.2.5
  * Mesa 10.2.5 is a bug fix release which fixes bugs fixed since
    the 10.2.4 release
* Tue Jul 29 2014 tiwai@suse.de
- Reduce error log level for annoying dlopen messages (bnc#889391)
  U_mesa-glx-Reduce-error-log-level.patch
* Mon Jul 21 2014 sndirsch@suse.com
- Update to version 10.2.4
  * Mesa 10.2.4 is a bug fix release which fixes bugs fixed since
    the 10.2.3 release
* Wed Jul  9 2014 sndirsch@suse.com
- Update to version 10.2.3
  * Mesa 10.2.3 is a bug fix release which fixes bugs fixed since
    the 10.2.2 release
- obsoletes u_mesa-gallium-llvmpipe-fix-SIGFPE.patch
* Sun Jun  8 2014 tobias.johannes.klausmann@mni.thm.de
- Update to version 10.2.1
- Mesa 10.2.1 is an emergency release to fix a build failure added
  to 10.2 between 10.2-rc5 and the final release.
- Mesa 10.2 is a feature release that includes many updates and
  enhancements. The full list is available in the release notes
  file in docs/relnotes/10.2.html.
* Wed Jun  4 2014 sndirsch@suse.com
- Update to version 10.2-rc5
  Another round of bugfixes towards the final 10.2
* Tue May 27 2014 tiwai@suse.de
- Fix zero-division with empty height (bnc#879462)
  u_mesa-gallium-llvmpipe-fix-SIGFPE.patch
* Mon May 26 2014 tobias.johannes.klausmann@mni.thm.de
- Update to version 10.2-rc4:
  Another round of bugfixes towards the final 10.2
* Mon May 19 2014 tobias.johannes.klausmann@mni.thm.de
- Update to 10.2-rc3
  Even more bugfixes
* Mon May 12 2014 schwab@suse.de
- no shared llvm libs on ppc64
- vdpau no longer enabled by default
- xa or gallium-gbm implies gallium-loader
* Sat May 10 2014 tobias.johannes.klausmann@mni.thm.de
- Update to 10.2-rc2:
  More bugfixes
* Sat May  3 2014 tobias.johannes.klausmann@mni.thm.de
- Update to 10.2-rc1:
- Remove U_gallium_util_add_missing_u_math_include.patch (patch27)
- Remove U_nouveau_create_only_one_shared_screen.patch (patch28)
- Remove U_nouveau_add_valid_range_tracking.patch (patch29)
- Remove U_nouveau_fix_fence_waiting_logic.patch (patch30)
* Fri Apr 25 2014 tobias.johannes.klausmann@mni.thm.de
- Add missing BuildRequires, remove old xorg-x11-*-devel packages
* Mon Apr  7 2014 schwab@suse.de
- Include XA tracker sub packages on s390x
* Mon Mar 31 2014 schwab@suse.de
- Clean up specfile
- Turn negative arch checks into positive ones for non-default configure
  settings
- libxsmfence is also available on ppc64le
- Don't enable gallium-egl on ppc64 for now to work around llvm bug
* Thu Mar 13 2014 tobias.johannes.klausmann@mni.thm.de
- Add U_gallium_util_add_missing_u_math_include.patch (patch27)
- Add U_nouveau_create_only_one_shared_screen.patch (patch28)
- Add U_nouveau_add_valid_range_tracking.patch (patch29)
- Add U_nouveau_fix_fence_waiting_logic.patch (patch30)
  + https://bugzilla.novell.com/show_bug.cgi?id=866445
  + https://bugs.freedesktop.org/show_bug.cgi?id=75279
* Wed Mar  5 2014 tobias.johannes.klausmann@mni.thm.de
- Update to version 10.1:
- New features:
  + GL_ARB_draw_indirect on i965.
  + GL_ARB_clear_buffer_object
  + GL_ARB_viewport_array on i965.
  + GL_ARB_map_buffer_alignment on all drivers that did not previously
    support it.
  + GL_AMD_shader_trinary_minmax.
  + GL_EXT_framebuffer_blit on r200 and radeon.
  + Reduced memory usage for display lists.
  + OpenGL 3.3 support on nv50, nvc0, r600 and radeonsi
- Changes:
  + Removed support for the GL_MESA_texture_array extension.
* Tue Feb  4 2014 sndirsch@suse.com
- Update to version 10.0.3
  * Mesa 10.0.3 is a bug fix release which fixes bugs fixed since
    the 10.0.2 release
* Wed Jan 15 2014 afaerber@suse.de
- Enable freedreno gallium driver (Qualcomm Adreno)
* Mon Jan 13 2014 sndirsch@suse.com
- Update to version 10.0.2
  * Mesa 10.0.2 is a bug fix release which fixes bugs fixed since
  the 10.0.1 release.
* Tue Dec 17 2013 schwab@suse.de
- Make proper use of %%build and %%install
- Use verbose make rules
* Mon Dec 16 2013 schwab@suse.de
- Fix filelist: /etc/drirc is now always installed
* Sat Dec 14 2013 tobias.johannes.klausmann@mni.thm.de
- Update to version 10.0.1:
  This version of Mesa fixes the regression that Mesa 10.0 could not
  be loaded by any released version of the X server.
* Fri Dec  6 2013 adrian@suse.de
- disable llvm support for ppc64le, llvm does not support ppc64le
* Mon Dec  2 2013 sndirsch@suse.com
- disable the build of egl-wayland support on openSUSE 12.3, since
  Mesa 10.0 requires a higher wayland version than we have on
  openSUSE 12.3
* Wed Nov 27 2013 tobias.johannes.klausmann@mni.thm.de
- Update to version 10.0.0:
  Mesa 10.0 has been released! Mesa 10.0 is a feature release that
  includes many updates and enhancements. The full list is available in
  the release notes file in docs/relnotes/10.0.html.
- Remove libXvMC_{r300,softpipe} packages
- Remove libvdpau_{r300,softpipe} packages
- Bump libxatracker package version
* Sat Nov 16 2013 hrvoje.senjan@gmail.com
- Update to version 9.2.3
  * st/mesa: move out of memory check in st_draw_vbo()
  * osmesa: fix broken triangle/line drawing when using float
  color buffer
  * Remove error when calling glGenQueries/glDeleteQueries while
  a query is active
  * Bump version to 9.2.3
  * i965: CS writes/reads should use I915_GEM_INSTRUCTION
  * i965: Fix texture buffer rendering after a whole buffer
  replacement.
  * i965: Emit post-sync non-zero flush before
  3DSTATE_GS_SVB_INDEX.
  * i965: Emit post-sync non-zero flush before
  3DSTATE_DRAWING_RECTANGLE.
  * i965: Also guard 3DSTATE_DRAWING_RECTANGLE with a
  flush in blorp.
  * i965: Move post-sync non-zero flush for 3DSTATE_MULTISAMPLE.
  * i965: Also emit HIER_DEPTH and STENCIL packets when
  disabling depth.
  * i965: Also emit HiZ and Stencil packets when
  disabling depth on Gen6.
  * wayland: Don't rely on static variable for
  identifying wl_drm buffers
  * radeonsi: fix blitting the last 2 mipmap levels of
  compressed textures
  * meta: enable vertex attributes in the context of the
  newly created array object
  * mesa: fixes for MSVC 2013
* Tue Nov 12 2013 schwab@suse.de
- Add support for m68k
* Fri Oct 25 2013 sndirsch@suse.com
- no longer install install libvdpau_r300 subpackage by default and
  update descriptions of libvdpau_{nouveau,r600,radeonsi,softpipe}
  subpackages (bnc#847269)
* Thu Oct 24 2013 sndirsch@suse.com
- install libvdpau_{nouveau,r300,r600,radeonsi} package on
  appropriate hardware by default (bnc#847269)
* Sat Oct 19 2013 hrvoje.senjan@gmail.com
- Update to version 9.2.2
  * Valgrind error in program_resource_visitor::recursion, (fdo#69449)
  * glInvalidateFramebuffer fails with GL_INVALID_ENUM (fdo#70411)
  * svga: fix incorrect memcpy src in svga_buffer_upload_piecewise()
  * mesa: consolidate cube width=height error checking
  * mesa: Add missing switch break in invalidate_framebuffer_storage()
  * i965: Don't forget the cube map padding on gen5+.
  * mesa: Fix compiler warnings when ALIGN's alignment is "1 << value".
  * i965: Fix 3D texture layout by more literally copying from the spec.
  * glsl: Fix usage of the wrong union member in
  program_resource_visitor::recursion.
  * radeonsi: Use 'SI' as the LLVM processor for CIK on LLVM <= 3.3
* Sat Oct  5 2013 hrvoje.senjan@gmail.com
- Update to version 9.2.1
  * Use of uninitialized stack variable with brw_search_cache()
  (fdo#66779)
  * Valgrind errors in mesa (fdo#68233)
  * Automatic mipmap generation with texture compression produces
  borders that fade to black (fdo#68250)
  * Unigine demo crash (fdo#68637)
  * GLSL ES: structs members can't have precision qualifiers
  anymore in 9.2 (fdo#68753)
  * Piglit tex-shadow2drect fails (fdo#69525)
- Dropped U_radeon-winsys-pad-IBs-to-a-multiple-of-8-DWs.patch,
  U_wayland-egl-pc-require-wayland.patch and
  u_gallium-egl-gbm-use-wayland-cflags.patch they are included in
  this release
* Mon Sep 23 2013 idonmez@suse.com
- Enable llvmpipe on PPC64
* Fri Sep 20 2013 sndirsch@suse.com
- Disable u_mesa-8.0-llvmpipe-shmget.patch,
  u_mesa-8.0.1-fix-16bpp.patch since these are considered wrong by
  the author
- remove libIndirectGL (packages), since it is most likely no
  longer used by anyone ...
- use --enable-osmesa, since we no longer have this extra build
  for libIndirectGL
* Tue Sep 17 2013 hrvoje.senjan@gmail.com
- Added U_radeon-winsys-pad-IBs-to-a-multiple-of-8-DWs.patch from
  upstream -- aligns the gfx, compute, and dma IBs to 8 DW boundries.
  Additionally, r6xx hardware requires at least 4
  DW alignment to avoid a hw bug.  This also aligns the DMA
  IBs to 8 DW which is required for the DMA engine.
* Mon Sep 16 2013 sndirsch@suse.com
- updated to latest available version of
  * u_mesa-8.0-llvmpipe-shmget.patch
  * u_mesa-8.0.1-fix-16bpp.patch
  and applying it now in the opposite order.
* Fri Sep 13 2013 duwe@suse.com
- wayland-egl-pc-require-wayland is now mainline
* Thu Sep 12 2013 schwab@suse.de
- drirc is only installed if there are hardware DRI drivers
* Tue Sep 10 2013 tobias.johannes.klausmann@mni.thm.de
- Remove custom drirc, ship the upstream drirc
* Tue Sep 10 2013 tobias.johannes.klausmann@mni.thm.de
- Drop upstreamed patches as proposed by Johannes Obermayr:
  + Patch14: u_mesa-glapi_dispatch.patch
    Upstream: http://cgit.freedesktop.org/mesa/mesa/commit/?id=5ea43e6
  + Patch17: u_mesa-9.0-i965-Make-sure-we-do-render-between-two-hiz-flushes.patch
    Upstream: http://cgit.freedesktop.org/mesa/mesa/commit/?id=1dfea55
* Mon Sep  9 2013 duwe@suse.com
- u_wayland-egl-pc-require-wayland.patch: after finding wayland
  for egl, make sure its pkconfig is used as well.
* Fri Aug 30 2013 idonmez@suse.com
- Enable llvmpipe and xa on s390x
* Tue Aug 27 2013 tobias.johannes.klausmann@mni.thm.de
- Update to final version 9.2:
  Mesa 9.2 has been released! Mesa 9.2 is a feature release that includes
  many updates and enhancements.
- New features:
  + GL_ARB_shading_language_420pack in all drivers that support GLSL 1.30.
  + GL_ARB_texture_buffer_range
  + GL_ARB_texture_multisample
  + GL_ARB_texture_storage_multisample
  + GL_ARB_texture_query_lod
  + Enable GL_ARB_texture_storage on radeon, r200, and nouveau
  + GL_EXT_discard_framebuffer in all OpenGL ES (all versions) drivers
  + GL_EXT_framebuffer_multisample_blit_scaled on i965
  + Added new freedreno gallium driver
  + OSMesa interface for gallium llvmpipe/softpipe drivers
  + Gallium Heads-Up Display (HUD) feature for performance monitoring
  + Added support for UVD (2.2 and 3.0) video decoding on r600g and radeonsi
    through VDPAU (requires Kernel 3.10 or later)
- Changes:
  + Removed d3d1x state tracker (unused, unmaintained and broken)
  + Removed GL_EXT_clip_volume_hint because no driver had enabled it since 2007.
  + Removed GL_MESA_resize_buffers because it was only really implemented by the
    (unsupported) GDI driver.
  + GL_EXT_separate_shader_objects has been removed from all Gallium drivers,
    because it disallows a critical GLSL shader optimization.
    GL_ARB_separate_shader_objects doesn't have this issue.
  + i965 Gen6+ requires Kernel 3.6 or later. (92d2f5a)
* Fri Aug 23 2013 hrvoje.senjan@gmail.com
- Stop versioning libgbm1/devel and libwayland-egl/devel by itself,
  they now follow general Mesa version
* Fri Aug 23 2013 hrvoje.senjan@gmail.com
- Fix baselibs from previous change (there is no Mesa-libEGL1-devel),
  but Mesa-libEGL-devel
* Fri Aug 23 2013 hrvoje.senjan@gmail.com
- Update to 9.2 rc2
  * Documentation, glsl and buildsystem fixes since rc1
- baselibs.conf cleanup: adjusted to current spec
* Tue Aug 20 2013 hrvoje.senjan@gmail.com
- Update to 9.2 rc1
  * bugfixes over previous snapshot
* Tue Aug 13 2013 dmueller@suse.com
- fix build on armv7
* Mon Aug 12 2013 hrvoje.senjan@gmail.com
- Update to new snapshot from 9.2 branch:
  * various bugfixes since the previous snapshot
  * i965 Gen6+ requires Kernel 3.6 or later
  * Added support for UVD (2.2 and 3.0) video decoding on r600g and
  radeonsi through VDPAU (requires Kernel 3.10 or later)
* Thu Aug  8 2013 schwab@suse.de
- Don't enable gallium-egl without Gallium
- Enable llvm_r600 only on %%ix86 x86_64
* Mon Jul 29 2013 sndirsch@suse.com
- Make a symlink to libGL.so.1.2 for compatibility (bnc#809359,
  bnc#831306)
- u_mesa-9.0-i965-Make-sure-we-do-render-between-two-hiz-flushes.patch
  * Prevent hangs with rc6. (bnc#804910, bnc#831306)
* Thu Jul 25 2013 dvaleev@suse.com
- adjust filelist so powerpc build could succeed
- disable llvm_r600 for powerpc for now.
* Wed Jul 17 2013 sndirsch@suse.com
- The llvm with the R600 backend is finally in Factory, lets use it :)
* Fri Jul  5 2013 hrvoje.senjan@gmail.com
- Update to 9.2 snapshot:
  * New features:
  * Mesa 9.2 implements the OpenGL 3.1 API - OpenGL 3.1 is only
  available if requested at context creation because
  GL_ARB_compatibility is not supported
  * GL_ARB_texture_buffer_range
  * GL_ARB_texture_multisample
  * GL_ARB_texture_storage_multisample
  * GL_ARB_texture_query_lod
  * Enable GL_ARB_texture_storage on radeon, r200, and nouveau
  * Added new freedreno gallium driver
  * OSMesa interface for gallium llvmpipe/softpipe drivers
  * Gallium Heads-Up Display (HUD) feature for performance monitoring
  * Changes:
  * Removed d3d1x state tracker (unused, unmaintained and broken)
  * Removed GL_EXT_clip_volume_hint because no driver had enabled
  it since 2007.
  * Removed GL_MESA_resize_buffers because it was only really
  implemented by the (unsupported) GDI driver.
  * GL_EXT_separate_shader_objects has been removed from all Gallium
  drivers, because it disallows a critical GLSL shader optimization.
  GL_ARB_separate_shader_objects doesn't have this issue.
- Unlock radeonsi libvdpau
- Enable gallium egl
- added U_gallium-egl-gbm-use-wayland-cflags.patch, needed so gbm
  uses pkgconfig flags, instead of relying on "common" wayland dir
- Added llvm_r600 define, for enableing llvm shared-libs and
  r600-llvm-compiler. Off for now, until we have fixed llvm
* Tue Jul  2 2013 hrvoje.senjan@gmail.com
- Update to Mesa 9.1.4:
  * [bisected i965] Bus error (core dumped) on oglc texdecaltile
  (fdo#37871)
  * egl/opengles1/tri_x11 renders wrong (fdo#42182)
  * [SNB IVB HSW] mesa demo test texleak bus error (fdo#44958)
  * [snb] crash in texsubimage to a large atlas in clutter
  (fdo#53494)
  * glDrawElements segfault when compiled into display list
  (fdo#60518)
  * src/mesa/drivers/dri/common/xmlpool.h:96:29: fatal error:
  xmlpool/options.h (fdo#61821)
  * r300g regression (RV380): Strange rendering of light sources in
  Penumbra (bisected) (fdo#63520)
  * [HSW] support new haswell graphics [8086:0a2e] (fdo#63701)
  * [gm45, bisected] some piglit glsl 1.10 built-in-functions tests
  crash (fdo#64727)
  * [llvmpipe] SIGSEGV src/gallium/state_trackers/glx/xlib/glx_api.c:1374
  (fdo#64745)
  * [llvmpipe] SIGSEGV src/gallium/state_trackers/glx/xlib/glx_api.c:1363
  (fdo#64934)
  * segfault in _mesa_get_format_datatype and _mesa_get_color_read_type
  when state dumping with glretrace (fdo#65173)
- Droped llvm-3.3.patch, it's included in this release
* Tue May 28 2013 mhrusecky@suse.com
- fixed compilation against latest lvm: llvm-3.3.patch
* Tue May 21 2013 hrvoje.senjan@gmail.com
- update to Mesa 9.1.3:
  * Second Life viewers from release 2.7.4.235167 to the last
  3.4.0.264911 crash on start. (fdo#39251)
  * [wine] GLX_DONT_CARE does not work for GLX_DRAWABLE_TYPE or
  GLX_RENDER_TYPE (fdo#47478)
  * [SNB bisected] SNB hang with rc6 and hiz on glxgears
  (and other GL apps) immediately after xinit. (fdo#56416)
  * [GLSL1.40 IVB/HSW]Piglit spec/glsl-1.40/compiler_built-in-functions/inverse-mat2.frag
  fails (fdo#57436)
  * [ivb] Mesa 9.1 performance regression on KWin's Lanczos
  shader (fdo#61554)
  * abort is an incredibly not-smart way to handle IR validation
  (fdo#61773)
  * solaris build broken with missing ffsll (fdo#62868)
  * glXChooseFBConfig with GLX_DRAWABLE_TYPE, GLX_DONT_CARE fails
  (fdo#62999)
  * EGL X11 Regression: Maximum swap interval is 0 (worked with 9.0)
  (fdo#63078)
  * [i965 Bisected]Ogles1conform/Ogles2conform/Ogles3conform cases
  segfault (fdo#63447)
  * [SNB 9.1 Bisected]Ogles2conform GL2ExtensionTests/depth_texture_cube_map/depth_texture_cube_map.test
  fail (fdo#64662)
* Thu May  2 2013 hrvoje.senjan@gmail.com
- update to Mesa 9.1.2:
  * [965gm] green artifacts when using GLSL in XBMC (fdo#44567)
  * many new symbols in libxatracker after recent automake work
  (fdo#59238)
  * [SNB/IVB/HSW Bisected]Oglc draw-buffers2(advanced.blending.none)
  segfault (fdo#59445)
  * [i965 Bisected]Oglc fbblit(advanced.blitFb-3d-cube.mirror.both)
  fails (fdo#59495)
  * [r300g] Unigine Heaven 3.0: all objects are black (fdo#60503)
  * Firefox 18.0.2 Crash On Nvidia GeForce2 (fdo#60510)
  * [SNB Bisected] kwin_gles screen corruption (fdo#61197)
  * [IVB] corrupt rendering with UBOs (fdo#61317)
  * glEdgeFlag can't be set to false (fdo#61395)
  * nullpointer dereference causes xorg-server segfault when nouveau
  DRI driver is loaded (fdo#61947)
  * llvmpipe: Fragment Shader with "return" in main causes back
  output (fdo#62357)
  * other bugfixes
- Drop u_remove-os-abi-tag.patch, fdo#26663 is fixed with this release
* Wed Apr  3 2013 dmueller@suse.com
- do not build x86* specific drivers on ARM, only enable
  nouveau,swrast,svga for ARM platforms
* Wed Apr  3 2013 coolo@suse.com
- fix baselibs.conf
* Thu Mar 21 2013 dvaleev@suse.com
- Don't enable xa on ppc and ppc64
- Fix glapi_dispatch #bfo56710 (u_mesa-glapi_dispatch.patch)
* Wed Mar 20 2013 hrvoje.senjan@gmail.com
- update to Mesa 9.1.1: a bugfix release
  * [GM45] mesa demos spriteblast render incorrectly (fdo#30232)
  * [gles2] Ironlake: gl_PointCoord takes no effect for point sprites
  (fdo#32429)
  * Mesa 7.11-devel implementation error: Unexpected program target
  in destroy_program_variants_cb() (fdo#38086)
  * [snb] corrupted GLSL built-in function results when using Uniform
  Buffer contents as arguments (fdo#57121)
  * Garbled UI in Team Fortress 2 and Counter-Strike: Source
  (fdo#58042)
  * Texture flicker with fragment shader (fdo#58960)
  * [i965]Oglc fbblit(advanced.blitFb-3d-cube.mirror.both) fails
  (fdo#59495)
  * [IVB] 3DMMES2.0 Taiji performance reduced by ~13%% with
  gnome-session enable compositing (fdo#59783)
  * build - libvdpau_softpipe fails at runtime. (fdo#60121)
  * gbm_dri_bo_create fails to initialize bo->base.base.format
  (fdo#60143)
  * Corruption with DMA ring on cayman (fdo#60802)
  * r600g: add htile support cause gpu lockup in Dishonored wine.
  (fdo#60848)
  * [softpipe] piglit interpolation-noperspective-gl_BackColor-flat-fixed
  regression (fdo#60938)
  * alloc_layout_array tx * ty assertion failure when making pbuffer
  current (fdo#61012)
  * Segfault in glBitmap when called with PBO source (fdo#61026)
* Mon Mar 18 2013 mmeister@suse.com
- Added Download Link to Source section in spec file
* Sat Mar  2 2013 tobias.johannes.klausmann@mni.thm.de
- Update to Mesa 9.1:
  Mesa 9.1 implements the OpenGL 3.1 API, but the version reported by
  glGetString(GL_VERSION) or glGetIntegerv(GL_MAJOR_VERSION) /
  glGetIntegerv(GL_MINOR_VERSION) depends on the particular driver
  being used. Some drivers don't support all the features required
  in OpenGL 3.1. OpenGL 3.1 is only available if requested at context
  creation because GL_ARB_compatibility is not supported.
- New features:
  + GL_ARB_map_buffer_alignment
  + GL_ARB_texture_cube_map_array
- Changes:
  + Removed VAAPI state tracker (unmaintained and broken)
  + Removed i965's broken hardware implementation of GL_NV_vertex_program
  + Removed swrast support for GL_NV_vertex_program
  + Removed swrast support for GL_NV_fragment_program
  + Removed OpenVMS support (unmaintained and broken)
- Changes to package(s):
  + Rename libwayland-egl1-devel -> libwayland-egl-devel
  + Add a GLES3 Development package
  + Removed patches:
  Mesa-nodate.diff (patch1)
    No dates are put into the build anymore
  U_glx-fix-glGetTexLevelParameteriv-for-indirect-render.patch (patch18)
    Included in this release
  + Remove BuildRequires we dont need:
    http://cgit.freedesktop.org/mesa/mesa/commit/?id=
    af6aeae4e1286a8858e040602db338de6a1367dc
  + Update Required package versions
* Thu Feb 28 2013 dmueller@suse.com
- only enable swrast for aarch64 for now
* Tue Feb 26 2013 stefan.bruens@rwth-aachen.de
- fix_glx_indirect_reply_bfo#59876.diff
  * GLX replies are parsed incorrectly when using libxcb and AIGLX,
    happens for most replies where data is embedded in the header.
    (bfo#59876, bnc#802718)
* Thu Feb 21 2013 hrvoje.senjan@gmail.com
- update to Mesa 9.0.3: a bugfix release
  * Pink artifacts on objects in the distance in ETQW/Quake 4
  (fdo#25201)
  * configure: Doesn't check for python libxml2 (fdo#31598)
  * [softpipe] piglit glsl-max-varyings regression (fdo#40404)
  * [bisected] Oglc pxconv-gettex(basic.allCases) regressed (fdo#47220)
  * [bisected i965]Oglc shad-compiler(advanced.TestLessThani)
  regressed(fdo#48629)
  * [swrast] piglit fbo-generatemipmap-filtering regression
  (fdo#54240)
  * [sandybridge][uxa] graphics very glitchy and always flickering
  (fdo#56920)
  * [GM45] Chrome experiment "Stars" crash: brw_fs_emit.cpp:708:
  brw_reg brw_reg_from_fs_reg(fs_reg*): Assertion „!"not reached"“
  failed. (fdo#57166)
  * build test failure: nouveau_fbo.c:198:3: error: too few arguments to
  function 'nouveau_renderbuffer_del' (fdo#57746)
  * [swrast] Mesa 9.1-devel implementation error: Unable to
  delete renderbuffer, no context (fdo#57754)
  * [IVB] Graphical glitches in 0 A.D (fdo#58680)
  * [softpipe] util/u_tile.c:795:pipe_put_tile_z: Assertion `0' failed.
  (fdo#58972)
  * [bisected] Mesa build fails: clientattrib.c:33:22: fatal error: indirect.h:
  No such file or directory (fdo#59364)
  * [ILK/SNB/IVB Bisected]Oglc vertexshader(advanced.TestLightsTwoSided)
  causes GPU hung (fdo#59700)
  * [swrast] piglit ext_framebuffer_multisample-interpolation 0
  centroid-edges regression (fdo#59873)
  * [Bisected]Piglit glx_extension_string_sanity fail (fdo#60052)
  * Planeshift: triangles where grass would be (fdo#60172)
* Mon Feb  4 2013 duwe@suse.com
- enable build of subpackage libwayland-egl1
* Thu Jan 24 2013 sndirsch@suse.com
- update to Mesa 9.0.2: a bugfix release
  * [KMS] mesa demo spectex broken on rv280 (fdo#22576)
  * KMS/R200: Bad shading in NWN since Mesa rewrite (fdo#26809)
  * [bisected regression] Oglc fbo(negative.invalidParams3)
  Segmentation fault (fdo#45877)
  * st_glsl_to_tgsi.cpp:4006:dst_register: Assertion
  `index < VERT_RESULT_MAX' failed (fdo#54402)
  * Memoryleak with glPopAttrib only on Intel GM45 (fdo#55175)
  * glcpp accepts junk after #else/#elif/#endif tokens (fdo#56442)
  * EGL sets error to EGL_SUCCESS when DRI driver fails to create
  context (fdo#56706)
  * Webgl conformance shader-with-non-reserved-words crash. (fdo#57622)
  * r200: Culling is broken when rendering to an FBO (fdo#57842)
  * r300g: blend sfactor=GL_DST_COLOR fails with FBOs (fdo#57984)
  * [llvmpipe] src/gallium/auxiliary/gallivm/lp_bld_tgsi_info.c:75:analyse_src: Assertion `src->Index < (sizeof(ctx->imm)/sizeof((ctx->imm)[0]))' failed. (fdo#58545)
  * src/glsl/tests/Makefile.am missing $(top_srcdir)/include (fdo#59383)
* Wed Jan 23 2013 sndirsch@suse.com
- reverted removing Libs.private/Requires.private in pkgconfig
  files
* Sat Jan 19 2013 dmueller@suse.com
- enable llvm backend also for ARM
* Fri Jan 18 2013 rbrownccb@opensuse.org
- Add requires for Mesa to Mesa-libGL1 in baselibs.conf
  * Mesa required for many applications in wine
  * wine-32bit pulls through Mesa-libGL1-32bit without Mesa-32bit
* Sat Jan  5 2013 crrodriguez@opensuse.org
- Remove Requires.private and Libs.private from *.pc files
  * Both are needed only for static linking
  * This package provides only shared libraries
  * the rpm pkgconfig dependency generator considers "Requires.private"
  a valid dependency even though there are no static libraries in the
  packages
  * This cause bloat and hides broken "buildRequires" in other packages.
* Fri Dec 14 2012 tobias.johannes.klausmann@mni.thm.de
- Remove unrecognized configure option "--disable-glu"
* Mon Dec 10 2012 sndirsch@suse.com
- Update to Version 9.0.1
  * bug fix release
* Tue Oct 16 2012 sndirsch@suse.com
- improved packages descriptions
* Mon Oct  8 2012 tobias.johannes.klausmann@mni.thm.de
- Update to version 9.0:
  Mesa 9.0 has been released.  Mesa 9.0 is a feature release.
  "The" big feature is the availability of OpenGL 3.1 on some
  supported hardware.
  + Remove the Git Commit ID
* Tue Sep 25 2012 tobias.johannes.klausmann@mni.thm.de
- Update the Mesa 9.0 Git Snapshot
  + Add the Git CommitID to the buildscript
  + Minor cleanup of the buildscript
* Mon Sep 24 2012 sndirsch@suse.com
- removed any .la file
- moved libglapi.so from Mesa-devel to Mesa-libglapi-devel package;
  Mesa-devel requires Mesa-libglapi-devel package anyway
* Fri Sep 21 2012 sndirsch@suse.com
- fixed libOSMesa packaging (only a dangling symlink has been
  packaged)
* Fri Sep 21 2012 coolo@suse.com
- fix baselibs.conf after package split
* Thu Sep 20 2012 sndirsch@suse.com
- instead of using "make install" for installing libIndirectGL/
  libOSMesa, do install these libs manually, so we no longer end
  up with linking *everything* against libIndirectGL (instead of
  having it correctly linked against GL!)
* Fri Aug 24 2012 tobias.johannes.klausmann@mni.thm.de
- Update to 8.1 prerelease:
  + Added radeonsi to the dri drivers for x86/x86_64
  + Rewrite the configuration parts of the spec file
  + Changed u_Fix-crash-in-swrast-when-setting-a-texture-for-a-pix.patch
    to apply!
  + Changed u_remove-os-abi-tag.patch to apply! (Removed parts of it)
  + Changed u_mesa-8.0.1-fix-16bpp.patch to apply! (Removed parts of it)
  + Remove upstreamed patches: (double checked)
  - upstream-llvm-patch.diff
  - U_i965-gen7-Reduce-GT1-WM-thread-count-according-to-up.patch
* Thu Aug 23 2012 fcrozat@suse.com
- Add u_mesa-8.0-llvmpipe-shmget.patch (Fedora): use shmget under
  llvmpipe, if available (bnc#766498).
- Update u_mesa-8.0.1-fix-16bpp.patch to work with shmget patch.
* Wed Aug  8 2012 tiwai@suse.de
- U_i965-gen7-Reduce-GT1-WM-thread-count-according-to-up.patch
  * Fix GPU hang with IVB GT1 desktop (bnc#775048)
* Tue Jul 10 2012 tobias.johannes.klausmann@mni.thm.de
- Update to Version 8.0.4 (minor bugfix release)
- Back to bz2 tarballs
* Sat Jun 16 2012 coolo@suse.com
- remove buildrequire on vim, it creates a pretty big cycle for
  no (obvious) benefit
* Tue Jun 12 2012 sndirsch@suse.com
- enabled build of XvMC/VDPAU state trackers for Nouveau, R300,
  R600, Softpipe (Software implementation)
* Tue Jun 12 2012 sndirsch@suse.com
- u_remove-os-abi-tag.patch
  * Remove OS ABI tag from libGL, so it is no longer preferred over
    libGLs without OS ABI tag (bnc#765294, fdo#26663)
* Fri Jun  8 2012 sndirsch@suse.com
- let libGL1-Mesa require Mesa, since that package includes the DRI
  drivers (including the "swrast" DRI driver for software rendering)
  (bnc#765241)
* Wed May 30 2012 fcrozat@suse.com
- Add u_mesa-8.0.1-fix-16bpp.patch (Fedora): fix 16bpp mode under
  llvmpipe.
* Sat May 26 2012 sndirsch@suse.com
- added configure options "--enable-gbm --enable-glx-tls" (required
  for glamor support)
* Fri May 25 2012 meissner@suse.com
- libxatracker is also not built on ppc*.
* Mon May 21 2012 sndirsch@suse.com
- Trivial change to Version 8.0.3; tarball from here:
  http://cgit.freedesktop.org/mesa/mesa/snapshot/mesa-8.0.3.tar.gz
* Wed May 16 2012 adrian@suse.de
- fix build on platforms without gallium (s390 & arm)
* Wed Apr 25 2012 tittiatcoke@gmail.com
- Added patches from upstream Master to enable building with
  llvm 3.1
* Wed Apr 25 2012 sndirsch@suse.com
- For full OpenGL 3.0 compliance, it is necessary to
  have floating-point textures, so Mesa is now compiled with
  "--enable-texture-float" parameter to have OpenGL 3.0 support.
- disabling glut/glw no longer required since it's no longer
  shipped with Mesa
* Mon Apr 23 2012 vljn@ovi.com
- Enable xa state tracker and svga gallium drivers (vmwgfx stack)
* Sun Apr 15 2012 ro@suse.de
- use same dri drivers on ia64 as on ppc (no drm_intel)
* Wed Mar 21 2012 ryanbach@adelphia.net
-- Updated software rasterizer to use llvmpipe the advanced,
-  multithreaded,software rasterizer if availaible for that
-  archetecture (ie. X86/X86-64).
* Wed Mar 21 2012 jengelh@medozas.de
- Adjust baselibs.conf for OSMesa soname change
* Wed Mar 21 2012 sndirsch@suse.com
- U_gallium-rtasm-properly-detect-SSE-and-SSE2.patch
  * gallium/rtasm: properly detect SSE and SSE2;  this should fix
    crashes on ancient processors. (bnc#728737)
* Thu Mar  1 2012 coolo@suse.com
- fix baselibs.conf after update of libOSMesa
- do not put the date in generated code, this breaks build-compare
  for little to no gain as we know the build date from rpm header
* Fri Feb 24 2012 sndirsch@suse.com
- Switch software rasterizer to llvmpipe (gallium driver now)
  * Performance improvement especially on multicore system.
- minimal specfile cleanup
* Fri Feb 24 2012 meissner@suse.de
- only require drm_intel on intel.
* Thu Feb 23 2012 sndirsch@suse.com
- Update to Mesa 8.0.1
  * Removed all DRI drivers that did not support DRI2.
    Specifically, i810, mach64, mga, r128, savage, sis, tdfx, and
    unichrome were removed.
  * Removed all remnants of paletted texture support. As required
    by desktop OpenGL, GL_COLOR_INDEX data can still be uploaded
    to a color (e.g., RGBA) texture. However, the data cannot be
    stored internally as color-index.
  * Removed support for GL_APPLE_client_storage extension.
  * Removed the classic Mesa r300 and r600 drivers, which are
    superseded by the gallium drivers for this hardware.
  * Removed the dead Gallium i965, cell and failover drivers,
    which were either broken and with nobody in sight to fix
    the situation or deprecated.
- obsoletes u_GLX-SWrast-Make-GLX-with-SWrast-enabled-work-on-olde.patch
  (git commit #63a6fd6603574c1c01324fbeb0863e39d3864c16)
- obsoletes U_Mesa-7.11-llvm3.patch
- obsoletes Mesa-llvm-3.0.patch
- disabled u_Fix-crash-in-swrast-when-setting-a-texture-for-a-pix.patch
  for now (obsolete as well?)
* Wed Feb 22 2012 jengelh@medozas.de
- use --enable-shared-dricore, saves ~33 MB
* Wed Feb 22 2012 sndirsch@suse.com
- readded build of non-gallium nouveau driver ("nouveau_vieux") to
  support again older NVIDIA GPUs
* Tue Feb 21 2012 coolo@suse.com
- fix requires of devel package in moving the %%package before the
  other packages that have custom versions.
  %%version in rpm is tricky - it's the _last_ version before the
  macro, not the main one.
* Tue Feb 21 2012 jengelh@medozas.de
- Split shared libraries per shlib pol.
* Sun Feb 12 2012 jengelh@medozas.de
- Update dependencies according to configure.ac,
  use pkgconfig symbols
- Parallel build with %%_smp_mflags
- Remove redundant tags/sections
* Thu Feb  9 2012 sndirsch@suse.com
- fixed buildreqs due to splitted xorg-x11-libs
* Thu Dec  1 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Thu Nov 17 2011 vljn@ovi.com
- Update to Mesa 7.11.1
  * U_glx-ignore-BadRequest-errors-from-DRI2Connect.diff included
* Thu Oct  6 2011 idonmez@suse.com
- Update Mesa-llvm-3.0.patch again to fix compilation
* Thu Sep 29 2011 idonmez@suse.com
- Update Mesa-llvm-3.0.patch for new llvm snapshot
* Thu Sep 15 2011 idonmez@suse.com
- Fix build with newest llvm, fdo#40754
* Tue Sep 13 2011 idonmez@suse.com
- Fix build with Factory
* Mon Sep 12 2011 sndirsch@suse.com
- revert previous change since it actually *broke* the build with
  Factory
* Mon Sep 12 2011 idonmez@suse.com
- Fix build with Factory too
* Fri Sep  9 2011 vljn@ovi.com
- Fix openSUSE 11.3 11.4 build
* Sun Sep  4 2011 vljn@ovi.com
- Update to Mesa 7.11 final
* Sun Sep  4 2011 meissner@suse.de
- llvm is only available for *x86* currently
* Tue Aug  9 2011 stefan.bruens@rwth-aachen.de
- add fix for bfo #28125 (DRI2 prevents indirect glx)
* Tue Aug  2 2011 mhopf@novell.com
- Obsolete Mesa-nouveau3d (included in standard Mesa package now)
- Also nuke from baselibs.conf
* Fri Jul 29 2011 mhopf@novell.com
- Update to Mesa 7.11-rc3
- U_Mesa-7.11-llvm3.patch: fix compatibility with llvm 3.0 (and pre-releases)
- gallium is now required for r300, r600
- nouveau is now built by default (except on < OS11.3)
* Thu Jul 28 2011 meissner@suse.de
- Also let ppc64 build the noveau driver, fixing build on ppc64.
* Sun Jul  3 2011 vljn@ovi.com
- Update Mesa 7.10.3
  * Few crashes and rendering fixes.
* Mon Jun 20 2011 sndirsch@novell.com
- libdrm-2.4.26-nouveau.diff
  * Fixes build of Mesa 7.10.2 nouveau driver with libdrm 2.4.26
  (fdo #35562)
* Thu Jun 16 2011 mhopf@novell.com
- Don't unpack MesaDemos during build; it's not needed any more.
* Fri Jun 10 2011 eich@suse.de
- u_Fix-crash-in-swrast-when-setting-a-texture-for-a-pix.patch:
  Update this patch closing a giant memory leak.
* Thu Jun  9 2011 eich@suse.de
- Replace patches:
  * add: u_GLX-SWrast-Make-GLX-with-SWrast-enabled-work-on-olde.patch
    This patch falls back to indirect rendering if SWrast doesn't work
    with older Xservers as no common configs/visuals can be found.
  * remove: Mesa_indirect_old_xserver_compatibility.diff
    this patch is superseded.
  * rename: 0001-Fix-crash-in-swrast-when-setting-a-texture-for-a-pix.patch
    to u_Fix-crash-in-swrast-when-setting-a-texture-for-a-pix.patch
* Sat Jun  4 2011 eich@suse.de
- Remove: intel-add-gem-string.patch
  This patch was barking up the wrong tree anyway.
  As discussed with Martin Grässlin from the Kwin project
  a patch from the upstream git master has been cherry-picked
  and added to kdebase4-workspace which makes this patch unneciessary.
  The patch to Kwin will become obsolete once Kwin is updated,
  this will be noticed easily in kdebase4-workspace.
* Tue May 24 2011 eich@suse.de
- Fix the driver directory search path in the spec file.
  This makes dri_driver_dir.diff obsolete.
* Thu May 19 2011 idoenmez@novell.com
- Add intel-add-gem-string.patch: Add back "GEM" string to Intel
  driver's version output to fix OpenGL effects in kwin.
* Tue May 17 2011 eich@suse.de
- Add packaging information for GLES2 devel files.
* Mon May 16 2011 eich@suse.de
- Add GLES2 support.
* Fri May  6 2011 mhopf@novell.com
- Update to 7.10.2
  * Many crash and rendering fixes
  * Fixes bug 678264 (Xserver crash with radeon/radeonhd UMS)
* Wed Mar 30 2011 fcrozat@novell.com
- Enable gallium driver for radeon and r600
* Sat Jan  8 2011 sndirsch@novell.com
- update to 7.10 final
* Mon Jan  3 2011 sndirsch@novell.com
- Update pre-7.10 state (git 96685a6)
  Fixes two screensaver GPU crashes on SandyBridge (xorg #32683)
* Mon Dec 20 2010 sndirsch@novell.com
- Update full mesa stack to pre-7.10 (git 32218e4).
  Fixes most of intel SandyBridge rendering issues.
- Set Mesa version to 7.9.801
- obsoletes commit-d316391.diff
- adjusted 0001-Fix-crash-in-swrast-when-setting-a-texture-for-a-pix.patch
* Sat Nov  6 2010 sndirsch@novell.com
- 0001-Fix-crash-in-swrast-when-setting-a-texture-for-a-pix.patch
  * Fix crash in swrast when setting a texture for a pixmap
    (bnc #641297)
- readd swrastg DRI driver
* Wed Nov  3 2010 sndirsch@novell.com
- exclude swrastg DRI driver (bnc #641297)
* Fri Oct  8 2010 meissner@suse.de
- --enable-gallium-nouveau also for PowerPC.
* Thu Oct  7 2010 sndirsch@novell.com
- commit-d316391.diff
  * i965: Fix gen6 pointsize handling to match pre-gen6. Fixes
    point-line-no-cull (bfo #30532)
* Tue Oct  5 2010 sndirsch@novell.com
- MesaLib 7.9
- obsoletes commit-73dab75.diff
* Thu Sep 30 2010 sndirsch@novell.com
- commit-73dab75.diff
  * i965: fallback lineloop on sandybridge for now (bfo #30420,
    comment #8)
* Wed Sep 29 2010 sndirsch@novell.com
- updated to MesaLib 7.9-RC2
* Mon Sep 27 2010 sndirsch@novell.com
- updated to MesaLib 7.9-RC1
* Wed Sep 15 2010 sndirsch@novell.com
- Mesa git master #83f5f50 (2010-09-14)
- obsoletes commit-4ebf07a.diff
* Wed Sep 15 2010 sndirsch@novell.com
- Mesa git master #fd328a (2010-09-11)
- commit-4ebf07a.diff
  * glx: Don't destroy DRI2 drawables for legacy glx drawables
    (bfo #30109)
* Thu Sep  9 2010 sndirsch@novell.com
- use TALLOC_LIBS/TALLOC_CFLAGS env. variables which obsolete the
  requirement for a patched libtalloc-devel package, i.e.
  talloc.pc is no longer required.
* Sun Aug 29 2010 sndirsch@suse.de
- Mesa git master #2dfd348 (2010-08-28)
- obsoletes libdrm_nouveau.diff.bz2, mesa-commit-06c72da.diff
- adjusted Mesa_indirect_old_xserver_compatibility.diff,
  dri_driver_dir.diff
- added libtalloc-devel bison flex libxml2-python to BuildRequires
- pkgconfig file for egl
* Fri Jul 23 2010 sndirsch@suse.de
- reenable build of mga DRI driver (bnc #466635)
* Tue Jul  6 2010 johannesobermayr@gmx.de
- bnc #620037
  * create nouveau_vieux_dri.so
  * add libdrm_nouveau.diff
  * separate Mesa-nouveau3d package
- fix some RPMLINT warnings
* Fri Jun 25 2010 sndirsch@suse.de
- Mesa 7.8.2
  * Various i965 and i915 driver fixes.
- adjusted Mesa_indirect_old_xserver_compatibility.diff,
  egl-buildfix.diff
* Wed Jun  9 2010 bg@novell.com
- sis does not work on hppa as well
* Mon Jun  7 2010 sndirsch@suse.de
- mesa-commit-06c72da.diff
  * intel: Update renderbuffers unconditionally in
    intelSetTexBuffer2() (bnc #610323)
* Sat May 22 2010 sndirsch@suse.de
- Mesa_indirect_old_xserver_compatibility.diff (revival)
  Workaround for enabling indirect rendering to older Xservers
  (bnc #469280, bnc #600672).
* Sat Apr 10 2010 sndirsch@suse.de
- removed legal check since affected source files no longer exist
- removed obsolete missing_Makefile.diff
- specfile cleanup
* Tue Apr  6 2010 sndirsch@suse.de
- Mesa 7.8.1
  * The primary purpose of this release is to fix a significant
    error in Mesa's copy of glxext.h and the libGL code that uses
    it. The release also contains some other bug fixes.
* Mon Mar 29 2010 sndirsch@suse.de
- update to 7.8 final release
* Thu Mar 18 2010 ro@suse.de
- use 7.8-rc1 tarballs
* Wed Mar 17 2010 ro@suse.de
- update to 7.8
  - dos, ggi and classic svga drivers removed along with
    their header files
- re-enable nouveau driver
* Sun Feb 28 2010 sndirsch@suse.de
- due to libdrm update disable build of nouveau driver for now
  (needs newer Mesa sources from git master)
* Fri Jan 22 2010 ro@suse.de
- fix build for ppc
* Tue Dec 22 2009 sndirsch@suse.de
- Mesa 7.7 final release
* Fri Dec 18 2009 sndirsch@suse.de
- Mesa 7.7 RC3
  * more bug fixes
* Tue Dec 15 2009 jengelh@medozas.de
- add baselibs.conf as a source
- enable parallel building
- build drivers for SPARC
* Tue Dec  8 2009 sndirsch@suse.de
- Mesa 7.7 RC2
  * more bug fixes
* Tue Dec  1 2009 sndirsch@suse.de
- Mesa 7.7 RC1
  * New features
  - VMware "SVGA" Gallium driver. This is a Gallium3D driver
    which targets the VMware virtual graphics device. It allows
    Linux OpenGL guest applications to utilize the 3D graphics
    hardware of the host operating system.
  - GL_ARB_draw_elements_base_vertex (supported in Intel i965
    and software drivers)
  - GL_ARB_depth_clamp (supported in Intel i965 DRI and software
    drivers)
  - GL_NV_depth_clamp (supported in Intel i965 DRI and software
    drivers)
  - GL_ARB_provoking_vertex (same as GL_EXT_provoking_vertex)
  - Wavefront .obj file loader/viewer demo (progs/demos/
    objviewer)
  * Bug fixes
  - Many assorted i965 driver fixes.
  - Many r300-gallium driver fixes; this driver is now
    considered unstable-quality instead of experimental-quality.
  * Changes
  - New Mesa texture/surface format infrastructure
  - Removed some unused Mesa device driver hooks
* Wed Oct  7 2009 mhopf@novell.com
- Add -DNDEBUG to CFLAGS.
  It's unfortunate, but a few newly added assert()s for testing memory leaks
  trigger in this release. But having memory leaks is less problematic than
  crashing compiz.
* Tue Sep 29 2009 sndirsch@suse.de
- Mesa 7.6
  * OpenVG front-end (state tracker for Gallium). This was written
    by Zack Rusin at Tungsten Graphics.
  * GL_ARB_vertex_array_object and GL_APPLE_vertex_array_object
    extensions (supported in Gallium drivers, Intel DRI drivers,
    and software drivers)
  * GL_ARB_copy_buffer extension (supported in Gallium drivers,
    Intel DRI drivers, and software drivers)
  * GL_ARB_map_buffer_range extension (supported in Gallium drivers,
    Intel DRI drivers, and software drivers)
  * GL_ARB_seamless_cube_map extension (supported in software drivers
    and i965 drivers)
  * GL_ARB_vertex_array_bgra (ARB synonym for GL_EXT_vertex_array_bgra)
  * GL_ARB_sync (supported in software drivers and Intel DRI drivers)
  * GL_EXT_provoking_vertex extension (supported in Gallium, i915, i965,
    and software drivers)
  * Rewritten radeon/r200/r300 driver using a buffer manager
  * radeon/r200/r300 GL_EXT_framebuffer_object support when used with
    kernel memory manager
  * radeon/r200/r300 support for GL_ARB_occlusion_query
  * r300 driver supports OpenGL 1.5
  * r300 driver support for GL_EXT_vertex_array_bgra, GL_EXT_texture_sRGB
  * i915/945 driver support for GL_ARB_point_sprite, GL_EXT_stencil_two_side
    and GL_ATI_separate_stencil extensions
  * Rewritten assembler for GL_ARB_vertex_program / GL_ARB_fragment_program.
  * Added configure --with-max-width=W, --with-max-height=H options to
    specify max framebuffer, viewport size.
  * Initial version of Gallium llvmpipe driver. This is a new driver based
    on LLVM which makes exensive use of run-time code generation. This is
    an "alpha" stage driver. See the src/gallium/drivers/llvmpipe/README
    file for more information.
  * i965 DRI driver fixes, including support for "unlimited" size constant
    buffers (GLSL uniforms)
* Mon Sep 28 2009 sndirsch@suse.de
- Mesa 7.5.1
  * bug-fix release fixing issues found since the 7.5.1 release.
  - Detect B43 chipset in Intel driver
  - Assorted bug fixes for i965/i945 drivers
  - Fixed Gallium glDrawPixels(GL_STENCIL_INDEX) failure.
  - Fixed GLSL linker/preprocessor version directive issue seen
    in Wine (such as bug 23946)
  - glUseProgram() is now compiled into display lists (bug 23746).
  - glUniform functions are now compiled into display lists
  - Auto mipmap generation didn't work reliably with Gallium.
  - Fixed random number usage in GLX code.
  - Fixed invalid GL_OUT_OF_MEMORY error sometimes raised by
    glTexSubImage2D when using Gallium.
* Fri Sep 11 2009 sndirsch@suse.de
- no longer package glew headers in Mesa-devel, which caused file
  conflicts with glew-devel (bnc #538344)
* Thu Sep  3 2009 sndirsch@suse.de
- Mesa 7.5.1
  * bug-fix release fixing issues found since the 7.5 release.
* Sun Aug  2 2009 jansimon.moeller@opensuse.org
- add ARM variant to configure
* Fri Jul 31 2009 sndirsch@suse.de
- Mesa-devel should require libdrm-devel (bnc #527097)
* Sat Jul 18 2009 sndirsch@suse.de
- Mesa 7.5
  * new features like e.g. Gallium3D
  * various bug fixes
  * removed some GL_SGIX_* extensions, which have been superseded
    by ARB versions
- obsoletes mesa-commit-88b702e.diff, mesa-commit-954dfba.diff,
  intel_release_static_region.patch
* Wed Jun 24 2009 sndirsch@suse.de
- Mesa 7.4.4
  * Fixed i965/i915 segfault in screen destruction (bfo #22408)
- adjusted intel_release_static_region.patch
- obsoletes Mesa-intel_unref_fb.patch
* Tue Jun 23 2009 sndirsch@suse.de
- Mesa-intel_unref_fb.patch
  * intel: call _mesa_unreference_framebuffer() in
    intelDestroyBuffer(). This was a call to
    _mesa_reference_framebuffer(ptr, NULL) but the NULL pointer is
    incorrect in Mesa 7.4.x. Fixes a failed assertion during screen
    tear-down.
* Sat Jun 20 2009 sndirsch@suse.de
- Mesa 7.4.3
  * Fixed texture object reference counting bug (bug 21756)
  * Allow depth/stencil textures to be attached to GL_STENCIL_ATTACHMENT point
    (SF bug 2793846)
  * Added missing glGet case for GL_VERTEX_ARRAY_BINDING_APPLE
  * Fixed some OSMesa build issues
  * Fixed a vertex buffer object crash
  * Fixed broken glTexImage3D() when image type = GL_BITMAP
  * Fixed some GLSL preprocessor bugs
  * Fixed framebuffer mem leak in i945/i965 DRI drivers
  * Fixed texture coordinate repeat bug in swrast (bug 21872)
  * Fixed incorrect viewport clamping (lower bound is zero, not one)
  * GLX fix for glean's makeCurrent test case
- obsoletes reverted applied mesa_7_4_branch-commit-63cde0e.diff
* Tue May 19 2009 sndirsch@suse.de
- mesa_7_4_branch-commit-63cde0e.diff
  * commit, which introduced a regression; revert it (bnc #504578)
* Fri May 15 2009 sndirsch@suse.de
- Mesa 7.4.2
  * Fixed segfault when rendering to front buffer with DRI 1.
  * Fixed swrast texture rectangle bug when wrap mode =
    GL_CLAMP_TO_BORDER and filter mode = GL_LINEAR. (bug 21461)
  * Fixed texture object mem leak during context destruction.
  * Fixed a state validation bug in glCopyTex[Sub]Image()
  * Fixed some i965 GLSL bugs.
  * Fixed an R300 driver texture object bad memory reference.
* Wed Apr 22 2009 sndirsch@suse.de
- no longer package static libGL/libGLU; can't work any longer
  due to static X libraries having been removed
* Sat Apr 18 2009 sndirsch@suse.de
- Mesa 7.4.1
  * Fixed a two-sided lighting bug in fixed-function-to-GPU code
    generation
  * Fixed some Darwin issues (Jeremy Huddleston)
  * Indexing the GLSL gl_EyePlane[] or gl_ObjectPlane[] arrays
    with a variable was broken, bug 20986
  * Fixed incorrect texture unit bias in TXB instruction
  * glTexParameter settings weren't always propogated to drivers
  * Assorted vertex/fragment program bug fixes
  * Fixed point rendering in software rasterizer
  * Fixed potential deadlock in object hash functions
  * Fix a couple bugs surrounding front-buffer rendering with
    DRI2, but this is not quite complete.
  * Fixed glPopAttrib() bug when restoring user clip planes
* Sat Mar 28 2009 sndirsch@suse.de
- Mesa 7.4 (final)
  * This is a stable release that just fixes bugs since the 7.3
    release.
* Thu Mar 26 2009 sndirsch@suse.de
- Mesa 7.4-rc2
  * more patches cherry-picked from the master branch
* Sat Mar 21 2009 sndirsch@suse.de
- Mesa 7.4-rc1
* Sat Mar  7 2009 sndirsch@suse.de
- mesa-commit-954dfba.diff
  * i965: bump texture limit to 4kx4k (bfo #18100)
  * obsoletes i965-GL_MAX_TEXTURE_SIZE-4096.diff
- mesa-commit-88b702e.diff
  * i965: Eric Anholt's patch for bumping up texture sizes
    (bfo #18100)
* Fri Feb 27 2009 mhopf@suse.de
- Mesa_indirect_old_xserver_compatibility.diff
  Workaround for enabling indirect rendering to older Xservers
  (bnc #469280).
* Wed Feb 25 2009 sndirsch@suse.de
- update to Mesa 7.3
- obsoletes MesaLib-7.2_intel-2008-q3_793c3b9-46921a5.diff,
  commit-7d99ddc.diff, commit-b4bf9ac.diff,
  i965_aperture_call_for_Q3.patch, mesa-7.1-fix-i8xx-vbos.patch
* Tue Feb 10 2009 sndirsch@suse.de
- commit-7d99ddc.diff
  * intel: Fix a number of memory leaks on context destroy.
    (bnc #457879,bfo #19665)
- intel_release_static_region.patch
  * detach static region from intel_renderbuffer on contex destroy
    (bnc #457879,bfo #19665)
* Fri Jan 23 2009 sndirsch@suse.de
- added intel-i810-Mesa, Mesa7 to Provides/Obsoletes, i.e. get rid
  of SLE10 packages (bnc #468796)
* Wed Jan 14 2009 sndirsch@suse.de
- i965_aperture_call_for_Q3.patch (Quanxian Wang)
  * addresses bfo #19242; based on Q3 release; the patch is
    coming from commit id 59b2c2adbbece27ccf54e58b598ea29cb3a5aa85,
    2fc9d671e0be77676818da51cd3b35b52af79421,
    c30eb2c104c19c758c0b2a2461ad7f38cfa747d0
* Tue Jan 13 2009 olh@suse.de
- obsolete old XFree86-Mesa{,-devel}-XXbit packages (bnc#437293)
* Fri Jan  9 2009 sndirsch@suse.de
- /etc/drirc
  * disable vblank_mode/force_s3tc_enable and enable
    disable_lowimpact_fallback for r300 driver to fix performance
    issues with GoogleEarth and OpenOffice.Org (bnc #438666)
* Wed Dec 10 2008 olh@suse.de
- use Obsoletes: -XXbit only for ppc64 to help solver during distupgrade
  (bnc#437293)
* Fri Nov 28 2008 sndirsch@suse.de
- mesa-7.1-fix-i8xx-vbos.patch
  * For some reason the Intel 865 seem to claim VBO support in the
    docs, but doesn't seem to practice it in the hardware, or
    there is some missing errata. This restores the old pre-vbo
    code and uses it on all 8xx hw. (bfo #17963)
    This patch fixes OpenGL support on 845/855GM/865.
* Sat Nov 22 2008 sndirsch@suse.de
- disabled VBlank also for i965 DRI driver (bfo #17967)
* Mon Nov 17 2008 sndirsch@suse.de
- added global /etc/drirc to disable VBlank for i915 DRI driver
  (bnc #432980)
* Thu Nov 13 2008 sndirsch@suse.de
- disabled i965-GL_MAX_TEXTURE_SIZE-4096.diff; apparently it
  doesn't work for compiz/Desktop effects and is not required at
  all for 3D support in general (bnc #441572)
* Fri Oct 31 2008 sndirsch@suse.de
- commit-b4bf9ac.diff
  * i915: fix crash in i830_emit_state (bfo #17766)
* Thu Oct 30 2008 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Tue Oct 21 2008 sndirsch@suse.de
- MesaLib-7.2_intel-2008-q3_793c3b9-46921a5.diff
  * i965: Fix a potential assertion failure.
  * intel: GLSL 1.20 is broken in Mesa, so disable it in the i965
    driver
* Thu Oct  9 2008 sndirsch@suse.de
- Mesa 7.2_intel-2008-q3_793c3b9
  * Intel-2008-Q3-RC3 release (Mesa 7.2 + GEM code)
* Sat Sep 27 2008 sndirsch@suse.de
- Mesa 7.2_intel-2008-q3_e636f5b
  * Intel-2008-Q3-RC2 release (Mesa 7.2 + GEM code)
- replaced disable_ttm_warning.diff with disable_gem_warning.diff
- adjusted i965-GL_MAX_TEXTURE_SIZE-4096.diff
* Sat Sep 20 2008 sndirsch@suse.de
- Mesa 7.2:
  Mesa 7.2 is a stable release fixing bugs found in 7.1, which was
  a new development release. Mesa 7.2 implements the OpenGL 2.1
  API, but the version reported by glGetString(GL_VERSION) depends
  on the particular driver being used. Some drivers don't support
  all the features required in OpenGL 2.1. Note that this version
  of Mesa does not use the GEM memory manager. The master branch
  of git uses GEM. The prototype DRI2 code that was in 7.1 has
  also been removed. DRM version 2.3.1 should be used with Mesa 7.2
* Fri Aug 29 2008 sndirsch@suse.de
- added libexpat-devel to Buildrequires to fix build
* Thu Aug 28 2008 sndirsch@suse.de
- revert of commit-1724334.diff obsolete after adding the patches
  commit-5930aeb.diff/commit-78f50cd.diff (commits 5930aeb/78f50cd)
  to xorg-x11-server package (bfo #17069)
* Wed Aug 27 2008 sndirsch@suse.de
- updated to Mesa 7.1 final release
* Mon Aug 18 2008 sndirsch@suse.de
- reverted commit 1724334 to get RGB, Double-buffered visuals back;
  otherwise even GL applications like glxgears no longer start
  (bfo #17069)
* Sun Aug 17 2008 sndirsch@suse.de
- udpated to Mesa 7.1 RC4
  "This includes the latest GLSL fixes/features plus other assorted
  fixes from the past 2-3 weeks."
- obsoletes MesaLib-6befdca.diff
- adjusted disable_ttm_warning.diff (TTM --> GEM)
- adjusted i965-GL_MAX_TEXTURE_SIZE-4096.diff
* Mon Aug 11 2008 sndirsch@suse.de
- udpated to Mesa 7.1 RC3
  * bugfixes
* Mon Aug  4 2008 sndirsch@suse.de
- i965-GL_MAX_TEXTURE_SIZE-4096.diff
  * sets GL_MAX_TEXTURE_SIZE to 4096 for Intel 965 series
* Fri Aug  1 2008 sndirsch@suse.de
- commit-c71fa34.diff
  * added null texObj ptr check (bfo #15567, bnc #402687)
* Thu Jul 10 2008 sndirsch@suse.de
- even s390(x) needs swrast DRI driver now
- specfile cleanup
* Wed Jul  9 2008 sndirsch@suse.de
- no dri.pc for s390/s390x
* Tue Jul  8 2008 sndirsch@suse.de
- disable_ttm_warning.diff
  * disables confusing warning, that TTM cannot be initialized
* Fri Jul  4 2008 sndirsch@suse.de
- udpated to Mesa 7.1-pre
* Mon Apr 14 2008 sndirsch@suse.de
- unichrome-context.diff
  * Do not clear the current context before attempting to use it.
    (bnc #285496)
- no longer need to use LIBGL_ALWAYS_INDIRECT=1 on via hardware
  (bnc #285496)
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Sat Apr  5 2008 sndirsch@suse.de
- update to Mesa bugfix release 7.0.3 (final)
* Wed Apr  2 2008 sndirsch@suse.de
- update to Mesa bugfix release 7.0.3 RC3
  * obsoletes commit-185320a.diff
* Thu Mar 13 2008 sndirsch@suse.de
- commit-185320a.diff
  Only call ProgramStringNotify if program parsing succeeded.
  Wine intentionally tries some out-of-spec programs to test
  strictness, and calling ProgramStringNotify on the results
  of a failed program parse resulted in crashes in the 965
  driver. (bfo #13492)
* Fri Feb 22 2008 sndirsch@suse.de
- update to Mesa bugfix release 7.0.3 RC2
  * Fixed GLX indirect vertex array rendering bug (14197)
  * Fixed crash when deleting framebuffer objects (bugs 13507,
    14293)
  * User-defined clip planes enabled for R300 (bug 9871)
  * Fixed glBindTexture() crash upon bad target (bug 14514)
  * Fixed potential crash in glDrawPixels(GL_DEPTH_COMPONENT) (bug
    13915)
  * Bad strings given to glProgramStringARB() didn't generate
    GL_INVALID_OPERATION
  * Fixed minor point rasterization regression (bug 11016)
* Wed Jan 23 2008 sndirsch@suse.de
- update to Mesa bugfix release 7.0.3 RC1
  * Added missing glw.pc.in file to release tarball
  * Fix GLUT/Fortran issues
  * GLSL gl_FrontLightModelProduct.sceneColor variable wasn't
    defined
  * Fix crash upon GLSL variable array indexes (not yet supported)
  * Two-sided stencil test didn't work in software rendering
  * Fix two-sided lighting bugs/crashes (bug 13368)
  * GLSL gl_FrontFacing didn't work properly
  * glGetActiveUniform returned incorrect sizes (bug 13751)
  * Fix several bugs relating to uniforms and attributes in GLSL
    API (Bruce Merry, bug 13753)
  * glTexImage3D(GL_PROXY_TEXTURE_3D) mis-set teximage depth field
* Sat Nov 10 2007 sndirsch@suse.de
- updated to Mesa 7.0.2
  * New features:
  - Updated Windows VC7 project files
  - Added DESTDIR variable for 'make install'
  - Added pkg-config files for gl, glu, glut and glw libraries
  - Added bluegene-xlc-osmesa and catamount-osmesa-pgi configs
  - Support for Intel G33/Q33/Q35 graphics chipsets
  * Bug fixes:
  - Fixed a vertex buffer wrapping issue (bug 9962)
  - Added mutex protection around texture object reference
    counters
  - Added checking/support for additional chips in the i915/i945
    family (see 11978)
  - Fixed a blending/banding issue (bug 11931)
  - Fixed a GLU matrix inversion bug (#6748)
  - Fixed problem with large glDrawArrays calls and indirect
    rendering (bug 12141)
  - Fixed an assortment of i965 driver bugs
  - Fixed x86-64 vertex transformation bug (12216)
  - Fixed X server crash caused by multiple indirect rendering
    clients
  - Parsing of state.texgen in ARB vertex/fragment programs
    didn't work (bug 12313)
  - Fixed a glCopyPixels/glPixelZoom bug (12417)
  - Fixed a bug when using glMaterial in display lists (10604)
  - Fixed a few GLUT/Fortran issues (Bill Mitchell)
  - Fixed Blender crash bug (12164)
  - Fixed some issues preventing cross-compiling
  - Fixed up broken GL_ATI_separate_stencil extension
  - glDrawArrays(count=0) led to a crash
  - Fix SSE code gen memory leak, possible crash
  - Fixed MMX 565 rgb conversion problem (bug 12614)
  - Added -fno-strict-aliasing and -fPIC flags for gcc
  - Fixed Blender crash in Unichrome driver (bug 13142)
* Wed Nov  7 2007 sndirsch@suse.de
- updated to Mesa 7.0.2 RC2
  * added -fPIC and -fno-strict-aliasing flags for gcc
  * applied a few patches (mmx code, edgeflag ptr check)
  * r200 texture from pixmap fixes
- obsoletes pic.diff
* Sun Nov  4 2007 sndirsch@suse.de
- pic.diff
  * fixes shared lib on i386 (X.Org Bug #1809)
* Wed Oct 31 2007 sndirsch@suse.de
- updated to Mesa 7.0.2 RC1
- obsoletes disable-libGL-warning.diff, i915-g33.diff and
  i915tex-g33.diff
- adjusted link-shared.diff and static.diff
* Mon Aug 13 2007 sndirsch@suse.de
- disable-libGL-warning.diff:
  * Just filters warnings about unsupported non-conformant visuals
    instead of relying on the visual id. (X.Org Bug #6689)
* Sun Aug 12 2007 sndirsch@suse.de
- disable-libGL-warning.diff:
  * ignore unsupported visual 0x4b (Bug #247471, X.Org Bug #6689)
* Sat Aug  4 2007 sndirsch@suse.de
- updated to bugfix relelase 7.0.1
* Wed Jul  4 2007 sndirsch@suse.de
- i915-g33.diff/i915tex-g33.diff
  * support for G33/Q33/Q35
* Sat Jun 23 2007 sndirsch@suse.de
- updated to final release 7.0
* Thu Jun 21 2007 sndirsch@suse.de
- updated Mesa to release 7.0 RC1
  * Mesa 7.0 is a stable, follow-on release to Mesa 6.5.3. The only
    difference is bug fixes. The major version number bump is due
    to OpenGL 2.1 API support.
* Mon May 28 2007 sndirsch@suse.de
- move GL headers, which conflict with GL headers of NVIDIA driver,
  from Mesa-devel back to Mesa; this still make rpmlint happy
* Sat May 26 2007 dmueller@suse.de
- add missing ldconfig call to %%post
- move include files to -devel package
* Fri May 25 2007 dmueller@suse.de
- fix undefined symbols for i915 (#277744)
* Tue May 22 2007 dmueller@suse.de
- fix various undefined symbols in dri drivers (#272875)
- build parallel
* Mon May 14 2007 sndirsch@suse.de
- link-shared.diff:
  * use shared lib for DRI drivers to save a lot of space (Bug
    [#272875])
* Mon Apr 30 2007 sndirsch@suse.de
- updated to Mesa 6.5.3
- obsoletes the following patches:
  * bug-211314_mesa-destroy_buffers.diff
  * bug-211314_mesa-framebuffer-counting.diff
  * bug-211314-patch-1.diff
  * bug-211314-patch-2.diff
  * bug-211314-patch-3.diff
  * bug-211314-patch-4.diff
  * bug-211314-patch-5.diff
  * bug-211314-patch-6.diff
  * bug-211314-patch-7.diff
  * bug-211314-patch-8.diff
  * bug-211314-patch-9.diff
  * bug-211314-patch-10.diff
  * bug-211314-patch-11.diff
  * bug-211314_mesa-refcount-memleak-fixes.diff
  * Mesa-6.5.2-fix_radeon_cliprect.diff
* Fri Apr 27 2007 sndirsch@suse.de
- back to Mesa 6.5.2 (Bug #269155/269042)
* Wed Apr 25 2007 sndirsch@suse.de
- 4th RC ready
  * This fixes some breakage in RC3.
* Tue Apr 24 2007 sndirsch@suse.de
- 3rd release candidate
  * updated Windows/VC8 project files.
* Sun Apr 22 2007 sndirsch@suse.de
- updated to Mesa 6.5.3rc2
  * a number of bug fixes since the first RC
* Sat Apr 21 2007 sndirsch@suse.de
- updated to Mesa 6.5.3rc1
- obsoletes the following patches:
  * bug-211314_mesa-destroy_buffers.diff
  * bug-211314_mesa-framebuffer-counting.diff
  * bug-211314-patch-1.diff
  * bug-211314-patch-2.diff
  * bug-211314-patch-3.diff
  * bug-211314-patch-4.diff
  * bug-211314-patch-5.diff
  * bug-211314-patch-6.diff
  * bug-211314-patch-7.diff
  * bug-211314-patch-8.diff
  * bug-211314-patch-9.diff
  * bug-211314-patch-10.diff
  * bug-211314-patch-11.diff
  * bug-211314_mesa-refcount-memleak-fixes.diff
  * Mesa-6.5.2-fix_radeon_cliprect.diff
* Tue Apr 10 2007 sndirsch@suse.de
- Mesa-6.5.2-fix_radeon_cliprect.diff:
  * fixes X.Org Bug #9876
* Wed Apr  4 2007 sndirsch@suse.de
- bug-211314_mesa-refcount-memleak-fixes.diff:
  * Fix for memleaks and refount bugs (Bug #211314)
* Mon Mar 19 2007 sndirsch@suse.de
- no longer apply bug-211314_mesa-context.diff (Bug #211314,
  commment #114)
- added different Mesa patches (Bug #211314, comments #114/#115)
* Wed Mar 14 2007 sndirsch@suse.de
- removed libIndirectGL.so (Bug #254317)
- README.updates: new location of DRI drivers (Bug #254318)
* Wed Jan 24 2007 sndirsch@suse.de
- fixed build on ppc64/s390/s390x
* Thu Jan 18 2007 sndirsch@suse.de
- added libIndirectGL for indirect rendering only (Bug #234154)
* Wed Jan 17 2007 sndirsch@suse.de
- bug-211314_mesa-context.diff:
  * fixes Xserver crash in software rendering fallback (Bug #211314)
* Tue Jan  9 2007 sndirsch@suse.de
- disabled build of sis DRI driver on i64 to fix build
* Sat Dec  2 2006 sndirsch@suse.de
- updated to Mesa 6.5.2
  * New features
  - New DRI memory manager system. Currently used by the i915tex
    driver. Other DRI drivers will be updated to use the new memory
    manager in coming months. To use the new driver you'll need the
    most recent DRM library and drivers (version 2.2 or later) and a
    recent xf86-video-intel driver module from X.org. New features
    resulting from this work include:
  * EXT_framebuffer_objects, render to texture
  * ARB_pixel_buffer_objects
  * Accelerated CopyTexSubimage, DrawPixels, ReadPixels, CopyPixels
  * Accelerated texture uploads from pixel buffer objects
  * Potentially texturing directly from the pixel buffer object
    (zero copy texturing).
  - New Intel i965 DRI driver
  - New minstall script to replace normal install program
  - Faster fragment program execution in software
  - Added (or fixed) support for GLX_SGI_make_current_read to the
    following drivers:
  * radeon
  * savage
  * mga
  * tdfx
  - Added support for ARB_occlusion_query to the tdfx driver
    (Ian Romanick).
  * Bug fixes
  - fixed invalid memory read while rendering textured points (bug 8320)
  - fixed problems with freebsd-dri configuration (bug 8344)
  - Mesa's fake glxGetCurrentContext() wasn't thread-aware
  - OPTION NV_position_invariant didn't work in NV vertex programs
  - glDrawPixels into a user-created framebuffer object could crash Xlib driver
  - Line clipping was broken in some circumstances
  - fragment.fogcoord register didn't always contain the correct value
  - RGBA logicops didn't work reliably in some DRI drivers
  - Fixed broken RGBA LogicOps in Intel DRI drivers
  - Fixed some fragment program bugs in Intel i915 DRI driver
  - Fixed glGetVertexAttribfvARB bug 8883
  - Implemented glGetUniform[fi]vARB() functions
  - Fixed glDrawPixels(GL_COLOR_INDEX, GL_BITMAP) segfault (bug 9044)
  - Fixed some gluBuild2DMipmaps() bugs (Greg McGarragh)
  - Fixed broken "mgl" name mangling
  - Indirect rending was broken for glMap* functions (bug 8899)
  * Internal code changes
  - The device driver functions ResizeBuffers and GetBufferSize have
    been decprecated.
  - OpenGL 2.0 and 2.1 support is nearly done. We need to do quite a
    bit more testing of the shading language functions.
* Thu Nov 23 2006 sndirsch@suse.de
- enabled build of i965 DRI driver on x86_64
* Fri Nov 10 2006 sndirsch@suse.de
- fixed typos (Bug #219732)
* Wed Oct 18 2006 sndirsch@suse.de
- added static libGLU to Mesa-devel-static package (Bug #212532)
* Tue Oct 10 2006 sndirsch@suse.de
- fixed build on s390x
* Mon Oct  9 2006 sndirsch@suse.de
- i915-crossbar.diff:
  * fixes ARB_texture_env_crossbar extension (X.Org Bug #8292)
* Mon Sep 18 2006 sndirsch@suse.de
- updated to Mesa 6.5.1:
  New:
  * Intel i965 DRI driver
  * GL_APPLE_vertex_array_object extension (Ian Romanick)
  * GL_EXT_texture_sRGB extension
  * GL_EXT_gpu_program_parameters (Ian Romanick)
  * "engine" demo
  * updated fbdev driver and GLUT for fbdev (Sean D'Epagnier)
  * many updates to the DRI drivers
  Changes:
  * The glVertexAttribARB functions no longer alias the
    conventional vertex attributes.
  * glxinfo program prints more info with -l option
  * GL_FRAGMENT_PROGRAM_NV and GL_FRAGMENT_PROGRAM_ARB are now
    compatible, in terms of glBindProgramARB()
  * The GL_ARB_vertex_program attribute vertex.weight is now
    accepted by the parser, even though the GL_ARB_vertex_blend and
    GL_EXT_vertex_weighting extensions aren't supported. Allows Warcraft
    to run.
  Bug fixes:
  * fixed broken texture border handling for depth textures (bug 6498)
  * removed the test for duplicated framebuffer attachments, per
    version 117 of the GL_EXT_framebuffer_object specification
  * fixed a few render-to-texture bugs, including render to depth
    texture
  * clipping of lines against user-defined clip planes was broken
    (6512)
  * assembly language dispatch for SPARC was broken (bug 6484)
  * assorted compilation fixes on various Unix platforms (Dan Schikore)
  * glPopAttrib could restore an invalid value for GL_DRAW_BUFFER
  * assorted minor fixes for 16 and 32 bit/channel modes
  * fixed assorted bugs in texture compression paths
  * fixed indirect rendering vertex array crashes (bug 6863)
  * glDrawPixels GL_INDEX_OFFSET didn't always work
  * fixed convolution memory leak (bug 7077)
  * rectangular depth textures didn't work
  * invalid mode to glBegin didn't generate an error (bug 7142)
  * 'normalized' parameter to glVertexAttribPointerARB didn't work
  * disable bogus GLX_SGI_video_sync extension in xlib driver
  * fixed R128 driver locking bug (Martijn van Oosterhout)
  * using evaluators with vertex programs caused crashes (bug 7564)
  * fragment.position wasn't set correctly for point/line primitives
  * fixed parser bug for scalar sources for GL_NV_fragment_program
  * max fragment program length was incorrectly 128, now 1024
  * writes to result.depth in fragment programs weren't clamped to
    [0,1]
  * fixed potential dangling pointer bug in glBindProgram()
  * fixed some memory leaks (and potential crashes) in Xlib driver
* Sat Sep  9 2006 sndirsch@suse.de
- removed two source files with imcompatible license from Mesa
  tarball (Bug #204110)
- added a check to specfile to make sure that these will not be
  reintroduced with the next Mesa update again (Bug #204110)
* Mon Aug 21 2006 sndirsch@suse.de
- moved via profile.d scripts from x11-tools to this package
* Thu Aug 17 2006 sndirsch@suse.de
- dri_driver_dir.diff:
  * DEFAULT_DRIVER_DIR is set during make call in specfile
    (Bug #199958)
- disabled build of GLw (extra package MesaGLw)
* Mon Jul 31 2006 sndirsch@suse.de
- updated to Mesa 6.5_20060712; required by xorg-server 1.1.99.3
- cleanup
* Wed Jul 19 2006 ro@suse.de
- adapt to /usr/lib move
* Sun Jun 25 2006 sndirsch@suse.de
- fixed build for X.Org 7.1
* Wed Jun 21 2006 sndirsch@suse.de
- udpated to Mesa 6.5
  * obsoletes
  - Mesa-glx-x11-render-texture-2.diff
  - Mesa-radeon-large-textures-1.diff
  - Mesa_945GM.patch
  - mesa-6.4.2-dri-copy-sub-buffer-2.patch
  - mesa-6.4.2-scissor-fix-1.patch
- cleanup: removed no longer used sources/patches
  * missing-headers.diff
  * missing-headers.tar.bz2
  * glidelibs-i386.tar.gz
* Mon Jun 19 2006 sndirsch@suse.de
- added missing manual pages (Bug #185707)
* Fri Jun 16 2006 dreveman@suse.de
- Fix issue in copy-sub-buffer patch. Extension was not
  enabled on all radeon cards. (bnc 174839)
- Add radeon large texture patch (back port from latest stable
  release of Mesa). (bnc 174839)
* Tue May 23 2006 sndirsch@suse.de
- no longer remove NVIDIA installer in %%pre
* Mon May 22 2006 sndirsch@suse.de
- reverted Mesa/MesaGLU split
- fixed libGLcore.so.1 (e.g. soname); required to create a
  non-conflicting package for the NVIDIA driver (Bug #175683)
* Tue May 16 2006 sndirsch@suse.de
- splitted off MesaGLU/MesaGLU-devel
- added ldconfig to %%postun
* Sat Apr 22 2006 sndirsch@suse.de
- licensefix.patch:
  * fixed incompatible GPL license (Bug #133238, Mesa Bug #6490)
* Thu Apr 13 2006 sndirsch@suse.de
- added /usr/X11R6/%%{_lib}/modules/dri/updates/README.updates to
  document DRI driver update mechanism
* Wed Apr 12 2006 sndirsch@suse.de
- enhanced search path for DRI driver updates (FATE #300553)
* Mon Apr  3 2006 sndirsch@suse.de
- mesa-6.4.2-dri-copy-sub-buffer-1.patch:
  * needed for open source drivers to work with Xgl (David Reveman)
* Wed Mar 15 2006 mhopf@suse.de
- Fix for bug #157051, issue 1:
  On intel the graphics is only displayed correctly after a scissor region
  other than full screen is specified.
* Mon Feb  6 2006 sndirsch@suse.de
- update to Mesa 6.4.2 (obsoletes tnl_init.diff)
  * New items:
  - added OSMesaColorClamp() function/feature
  - added wglGetExtensionStringARB() function
  * Bug fixes:
  - fixed some problems when building on Windows
  - GLw header files weren't installed by installmesa script (bug 5396)
  - GL/glfbdev.h file was missing from tarballs
  - fixed TNL initialization bug which could lead to crash (bug 5791)
* Mon Feb  6 2006 sndirsch@suse.de
- tnl_init.diff (Mesa Bug #5791):
  * fixes TNL initialization bug which could lead to crash
    (CVS changelog: use calloc instead of malloc so try_codegen
    field is initialized to zero)
* Mon Jan 30 2006 sndirsch@suse.de
- glxext-sgi-hyperpipe.patch:
  * GLX_SGIX_hyperpipe_group -> GLX_SGIX_hyperpipe (Bug #146646)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan 20 2006 sndirsch@suse.de
- Mesa_945GM.patch:
  * 945GM support by Charles Johnson (FATE #151391)
* Wed Dec 28 2005 sndirsch@suse.de
- moved header files and libGL.so from Mesa-devel to Mesa to make
  uninstallation of nvidia driver in %%pre of Mesa-devel obsolete
* Wed Nov 30 2005 sndirsch@suse.de
- update to Mesa 6.4.1
* Fri Nov 18 2005 sndirsch@suse.de
- updated to Mesa 6.4 branch (2005-11-18)
- added static libGL (new Mesa-devel-static package)
- removed glut headers from installation (we use freeglut!)
* Tue Nov 15 2005 sndirsch@suse.de
- updated to Mesa 6.4 branch (2005-11-12)
* Wed Nov  9 2005 sndirsch@suse.de
- fixed libOSMesa build
* Tue Nov  8 2005 sndirsch@suse.de
- added build of libOSMesa, e.g. required by tulip package
* Tue Nov  8 2005 sndirsch@suse.de
- added include files for SGI's OpenGL Xt/Motif widgets, e.g.
  required by z88 package
  * GLwMDrawA.h
  * GLwDrawAP.h
  * GLwMDrawAP.h
  * GLwDrawA.h
- enabled Motif support in libGLw, also required by z88 package
* Mon Nov  7 2005 sndirsch@suse.de
- use glx headers from xorg-x11-devel package
* Fri Oct 28 2005 sndirsch@suse.de
- Mesa-glx-x11-render-texture-2.diff/missing-headers.diff:
  * new MESA_render_texture extension for Xgl (dreveman/mhopf)
* Tue Oct 25 2005 sndirsch@suse.de
- fixed DRI driver path for 64bit platforms
* Tue Oct 25 2005 sndirsch@suse.de
- update to Mesa 6.4
* Mon Oct 24 2005 sndirsch@suse.de
- build DRI compatible libGL
* Fri Oct 21 2005 sndirsch@suse.de
- added dummy nvidia libGLcore.so.1 for applications, which are
  still linked against libGL.so.1 of older nvidia driver releases
- duplicate libGL (located in /usr/lib/GL) to make workarounds
  like LD_PRELOAD possible if nvidia driver is installed and its
  libGl does not work
* Wed Oct 19 2005 sndirsch@suse.de
- no longer install libglide (disables 3Dfx DRI support)
* Sun Oct  2 2005 sndirsch@suse.de
- created package
